###############################################################################
# Licensed Materials - Property of IBM
#
# 5724-W86 5724-X63
#
# (C) Copyright IBM Corp. 2003, 2012. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
###############################################################################

package UserConfig;

@ISA    = qw(Exporter);
@EXPORT = qw(postparser_config);

use strict;
use Exporter ();

my @rules = (

    #-------------------------------------------------------------------------------
    # Part: Conversion to Watts of PUB_IP_RFS_Data, PUB_HIRS_RFS_Data, 
    #	    PUB_HIRS_ARIR_Data, PUB_IP_ARIR_Data counters
    # 
    # Formula --> W = 10^(dB/10) where dB is the value of the counter
    #-------------------------------------------------------------------------------

    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Convert PUB_IP_RFS_Data counter values to Watts',
        INPUT_FILE_DESCRIPTION => [ '.*PUB_IP_RFS_Data-#-I\.pif$' ],
        FILENAME_SUFFIX        => 'PZ',
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;

            my @ctrs2conv = (
                'MaxForwardPower',
                'MinForwardPower',
                'AvgForwardPower',
                'MaxRSSIInstant_M',
                'MinRSSIInstant_M',
                'AvgRSSIInstant_M',
                'MaxRSSIInstant_D',
                'MinRSSIInstant_D',
                'AvgRSSIInstant_D'
            );
            my ($ctr_name, $new_ctr_name);

            foreach $ctr_name (@ctrs2conv) {

                $new_ctr_name = $ctr_name . "_Watt";
                $c_ref->{$new_ctr_name} = 10**($c_ref->{$ctr_name}/10);
            }

            return 0;
        },
    },
    
    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Convert PUB_HIRS_RFS_Data counter values to Watts',
        INPUT_FILE_DESCRIPTION => [ '.*PUB_HIRS_RFS_Data-#-I\.pif$' ],
        FILENAME_SUFFIX        => 'PZ',
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;
	
	            if ( exists $c_ref->{MaxTP_dBm} ) {
	                $c_ref->{MaxTP_Watt} = 10**( $c_ref->{MaxTP_dBm}/10);
	            }
	            if ( exists $c_ref->{MinTP_dBm} ) {
	                $c_ref->{MinTP_Watt} = 10**($c_ref->{MinTP_dBm}/10);
	            }
	            if ( exists $c_ref->{AvgTP_dBm} ) {
	                $c_ref->{AvgTP_Watt} = 10**( $c_ref->{AvgTP_dBm}/10);
	            }
	            if ( exists $c_ref->{MaxRSSI_M_dBm} ) {
	                $c_ref->{MaxRSSI_M_Watt} = 10**($c_ref->{MaxRSSI_M_dBm}/10);
	            }
	            if ( exists $c_ref->{MinRSSI_M_dBm} ) {
	                $c_ref->{MinRSSI_M_Watt} = 10**( $c_ref->{MinRSSI_M_dBm}/10);
	            }
	            if ( exists $c_ref->{AvgRSSI_M_dBm} ) {
	                $c_ref->{AvgRSSI_M_Watt} = 10**($c_ref->{AvgRSSI_M_dBm}/10);
	            }
	            if ( exists $c_ref->{MaxRSSI_D_dBm} ) {
	                $c_ref->{MaxRSSI_D_Watt} = 10**($c_ref->{MaxRSSI_D_dBm}/10);
	            }
	            if ( exists $c_ref->{MinRSSI_D_dBm} ) {
	                $c_ref->{MinRSSI_D_Watt} = 10**( $c_ref->{MinRSSI_D_dBm}/10);
	            }
	            if ( exists $c_ref->{AvgRSSI_D_dBm} ) {
	                $c_ref->{AvgRSSI_D_Watt} = 10**($c_ref->{AvgRSSI_D_dBm}/10);
	            }	            	            

            return 0;
        },
    },    
    
    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Convert PUB_HIRS_ARIR_RF_Data counter values to Watts',
        INPUT_FILE_DESCRIPTION => [ '.*PUB_HIRS_ARIR_RF_Data-#-I\.pif$' ],
        FILENAME_SUFFIX        => 'PZ',
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;

   	            if ( exists $c_ref->{MaxARIRRSSI_M_dBm} ) {
	                $c_ref->{MaxARIRRSSI_M_Watt} = 10**( $c_ref->{MaxARIRRSSI_M_dBm}/10);
	            }
	            if ( exists $c_ref->{MinARIRRSSI_M_dBm} ) {
	                $c_ref->{MinARIRRSSI_M_Watt} = 10**($c_ref->{MinARIRRSSI_M_dBm}/10);
	            }
	            if ( exists $c_ref->{AvgARIRRSSI_M_dBm} ) {
	                $c_ref->{AvgARIRRSSI_M_Watt} = 10**( $c_ref->{AvgARIRRSSI_M_dBm}/10);
	            }
	            if ( exists $c_ref->{MaxARIRRSSI_D_dBm} ) {
	                $c_ref->{MaxARIRRSSI_D_Watt} = 10**($c_ref->{MaxARIRRSSI_D_dBm}/10);
	            }
	            if ( exists $c_ref->{MinARIRRSSI_D_dBm} ) {
	                $c_ref->{MinARIRRSSI_D_Watt} = 10**( $c_ref->{MinARIRRSSI_D_dBm}/10);
	            }
	            if ( exists $c_ref->{AvgARIRRSSI_D_dBm} ) {
	                $c_ref->{AvgARIRRSSI_D_Watt} = 10**( $c_ref->{AvgARIRRSSI_D_dBm}/10);
	            }	            
            
            return 0;
        },
    },    
    
    
    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Convert PUB_IP_ARIR_RF_Data counter values to Watts',
        INPUT_FILE_DESCRIPTION => [ '.*PUB_IP_ARIR_RF_Data-#-I\.pif$' ],
        FILENAME_SUFFIX        => 'PZ',
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;

            my @ctrs2conv = (
                'ARIRMaxRSSIInstant_M',
                'ARIRMinRSSIInstant_M',
				'ARIRAvgRSSIInstant_M',
				'ARIRMaxRSSIInstant_D',
				'ARIRMinRSSIInstant_D',
				'ARIRAvgRSSIInstant_D'
            );
            my ($ctr_name, $new_ctr_name);

            foreach $ctr_name (@ctrs2conv) {

                $new_ctr_name = $ctr_name . "_Watt";
                $c_ref->{$new_ctr_name} = 10**($c_ref->{$ctr_name}/10);

            }

            return 0;
        },
    },    
        
    #-------------------------------------------------------------------------------
    # Part: KPI Calculation for Busy Hours
    # LIF: Cell_Concurrent_Overview_1X, Cell_Concurrent_Overview_1X, Cell_Packet_Overview_1X, Cell_SMS_Overview_1X, 
    #      Cell_Voice_Overview_1X, DO_Cell_Traffic_Overview, PTT_Cell_Broadcast_traffic_overview, 
    #      PTT_Cell_group_traffic_overview, PTT_Cell_private_traffic_overview, Global_Concurrent_Overview_1X, 
    #      Global_Concurrent_Overview_1X, Global_Packet_Overview_1X, Global_SMS_Overview_1X, Global_Voice_Overview_1X, 
    #      DO_Global_Traffic_Overview, PTT_Global_Broadcast_traffic_overview, PTT_Global_group_traffic_overview, 
    #      PTT_Global_private_traffic_overviewDO_BSSB_Traffic, DO_BTS_Traffic, DO_Cell_Traffic
    # Rename --> Join --> Sum
    #-------------------------------------------------------------------------------

    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Rename data counters',
        INPUT_FILE_DESCRIPTION => [
            '.*1X_Cell_Concurrent_Voice_Paging-#-I\.pif',
            '.*1X_Cell_Concurrent_Voice_Originating_Call-#-I\.pif'
        ],
        FILENAME_SUFFIX        => 'PZ',
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;
            if ( exists $c_ref->{PageResponceNum} ) {
                $c_ref->{PageResponceNum_Voice_Nbr} = $c_ref->{PageResponceNum};
            }
            if ( exists $c_ref->{MSOriginateNum} ) {
                $c_ref->{MSOriginateNum_Voice_Nbr} = $c_ref->{MSOriginateNum};
            }
            return 0;
        },
    },
    
    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Rename data counters',
        INPUT_FILE_DESCRIPTION => [
            '.*1X_Cell_Concurrent_Packet_Originating_Call-#-I\.pif',
            '.*1X_Cell_Concurrent_Packet_Paging-#-I\.pif'
        ],
        FILENAME_SUFFIX        => 'PZ',
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;
            if ( exists $c_ref->{PageResponceNum} ) {
                $c_ref->{PageResponceNum_Packet_Nbr} = $c_ref->{PageResponceNum};
            }
            if ( exists $c_ref->{MSOriginateNum} ) {
                $c_ref->{MSOriginateNum_Packet_Nbr} = $c_ref->{MSOriginateNum};
            }
            return 0;
        },
    },    
    

    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for Cell_Concurrent_Overview_1X',
        INPUT_FILE_DESCRIPTION                    => [
            '(.*)1X_Cell_Concurrent_Voice_Paging-#-I-#-PZ\.pif',
            '(.*)1X_Cell_Concurrent_Voice_Originating_Call-#-I-#-PZ\.pif',
            '(.*)1X_Cell_Concurrent_Packet_Originating_Call-#-I-#-PZ\.pif',
            '(.*)1X_Cell_Concurrent_Packet_Paging-#-I-#-PZ\.pif',
        ],
        OUTPUT_BLOCK_NAME                         => 'Cell_Concurrent_Overview_1X',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId BtsId CellId CarrierId)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 0,
        OUTPUT_FILENAME_START                     => 'Cell_Concurrent_Overview_1X',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
    },
    

    {
        RULE_TYPE                 => 'AGGREGATE_LINE',
        RULE_DESC                 => 'Create Voice_call_number and Packet_call_number data counter by sum',
        INPUT_FILE_DESCRIPTION    => ['Cell_Concurrent_Overview_1X.*-#-J\.pif'],
        DEFAULT_NULL_VALUE        => '',
        COUNTER_GROUPS            => { Voice_call_number => '.*_Voice_Nbr',
        							   Packet_call_number => '.*_Packet_Nbr', },
        OUTPUT_BLOCK_NAME         => 'Cell_Concurrent_Overview_1X',
        PRODUCE_LIF               => 'True',
        PRODUCE_PIF               => 'True',
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
    },
        
    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Rename data counters',
        INPUT_FILE_DESCRIPTION => [
            '.*1X_Cell_Packet_Originating_Call-#-I\.pif',
            '.*1X_Cell_Packet_Paging-#-I\.pif'
        ],
        FILENAME_SUFFIX        => 'PZ',
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;
            if ( exists $c_ref->{AssignSoft_PagingMsNum} ) {
                $c_ref->{AssignSoft_PagingMsNum_Packet_Nbr} = $c_ref->{AssignSoft_PagingMsNum};
            }
            if ( exists $c_ref->{CMO_PagingMsNum} ) {
                $c_ref->{CMO_PagingMsNum_Packet_Nbr} = $c_ref->{CMO_PagingMsNum};
            }
            if ( exists $c_ref->{CMO_MSOriginateNum} ) {
                $c_ref->{CMO_MSOriginateNum_Packet_Nbr} = $c_ref->{CMO_MSOriginateNum};
            }
            if ( exists $c_ref->{AssignSoft_MSOriginateNum} ) {
                $c_ref->{AssignSoft_MSOriginateNum_Packet_Nbr} = $c_ref->{AssignSoft_MSOriginateNum};
            }
                       
            return 0;
        },
    },    
    

    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for Cell_Concurrent_Overview_1X',
        INPUT_FILE_DESCRIPTION                    => [
            '(.*)1X_Cell_Packet_Originating_Call-#-I-#-PZ\.pif',
            '(.*)1X_Cell_Packet_Paging-#-I-#-PZ\.pif'
        ],
        OUTPUT_BLOCK_NAME                         => 'Cell_Packet_Overview_1X',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId BtsId CellId CarrierId)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 0,
        OUTPUT_FILENAME_START                     => 'Cell_Packet_Overview_1X',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        
    },

    
    {
        RULE_TYPE                 => 'AGGREGATE_LINE',
        RULE_DESC                 => 'Create Packet_call_number data counter by sum',
        INPUT_FILE_DESCRIPTION    => ['Cell_Packet_Overview_1X.*-#-J\.pif'],
        DEFAULT_NULL_VALUE        => '',
        COUNTER_GROUPS            => { Packet_call_number => '.*_Packet_Nbr', },
        OUTPUT_BLOCK_NAME         => 'Cell_Packet_Overview_1X',
        PRODUCE_LIF               => 'True',
        PRODUCE_PIF               => 'True',
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
    },    

    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Rename data counters',
        INPUT_FILE_DESCRIPTION => [
            '.*1X_Cell_SMS_Originating_Call_on_TCH-#-I\.pif',
            '.*1X_Cell_SMS_Paging_on_TCH-#-I\.pif'
        ],
        FILENAME_SUFFIX        => 'PZ',
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;
            if ( exists $c_ref->{CMO_MSOriginateNum} ) {
                $c_ref->{CMO_MSOriginateNum_SMS_Nbr} = $c_ref->{CMO_MSOriginateNum};
            }
            if ( exists $c_ref->{AssignSoft_MSOriginateNum} ) {
                $c_ref->{AssignSoft_MSOriginateNum_SMS_Nbr} = $c_ref->{AssignSoft_MSOriginateNum};
            }
            if ( exists $c_ref->{AccProbe_MSOriginateNum} ) {
                $c_ref->{AccProbe_MSOriginateNum_SMS_Nbr} = $c_ref->{AccProbe_MSOriginateNum};
            }
            if ( exists $c_ref->{AccHo_MSOriginateNum} ) {
                $c_ref->{AccHo_MSOriginateNum_SMS_Nbr} = $c_ref->{AccHo_MSOriginateNum};
            }
            if ( exists $c_ref->{CMO_PageResponceNum} ) {
                $c_ref->{CMO_PageResponceNum_SMS_Nbr} = $c_ref->{CMO_PageResponceNum};
            }
            if ( exists $c_ref->{AssignSoft_PageResponceNum} ) {
                $c_ref->{AssignSoft_PageResponceNum_SMS_Nbr} = $c_ref->{AssignSoft_PageResponceNum};
            }
            if ( exists $c_ref->{AccProbe_PageResponceNum} ) {
                $c_ref->{AccProbe_PageResponceNum_SMS_Nbr} = $c_ref->{AccProbe_PageResponceNum};
            }
            if ( exists $c_ref->{AccHo_PageResponceNum} ) {
                $c_ref->{AccHo_PageResponceNum_SMS_Nbr} = $c_ref->{AccHo_PageResponceNum};
            }            
                       
            return 0;
        },
    },    
    

    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for Cell_SMS_Overview_1X',
        INPUT_FILE_DESCRIPTION                    => [
            '(.*)1X_Cell_SMS_Originating_Call_on_TCH-#-I-#-PZ\.pif',
            '(.*)1X_Cell_SMS_Paging_on_TCH-#-I-#-PZ\.pif'
        ],
        OUTPUT_BLOCK_NAME                         => 'Cell_SMS_Overview_1X',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId BtsId CellId CarrierId)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 0,
        OUTPUT_FILENAME_START                     => 'Cell_SMS_Overview_1X',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        
    },

    
    {
        RULE_TYPE                 => 'AGGREGATE_LINE',
        RULE_DESC                 => 'Create SMS_call_number data counter by sum',
        INPUT_FILE_DESCRIPTION    => ['Cell_SMS_Overview_1X.*-#-J\.pif'],
        DEFAULT_NULL_VALUE        => '',
        COUNTER_GROUPS            => { SMS_call_number => '.*_SMS_Nbr', },
        OUTPUT_BLOCK_NAME         => 'Cell_SMS_Overview_1X',
        PRODUCE_LIF               => 'True',
        PRODUCE_PIF               => 'True',
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
    },    

    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Rename data counters',
        INPUT_FILE_DESCRIPTION => [
            '.*1X_Cell_Voice_Originating_Call-#-I\.pif',
            '.*1X_Cell_Voice_Paging-#-I\.pif'
        ],
        FILENAME_SUFFIX        => 'PZ',
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;
            if ( exists $c_ref->{CMO_MSOriginateNum} ) {
                $c_ref->{CMO_MSOriginateNum_Voice_Nbr} = $c_ref->{CMO_MSOriginateNum};
            }
            if ( exists $c_ref->{AssignSoft_MSOriginateNum} ) {
                $c_ref->{AssignSoft_MSOriginateNum_Voice_Nbr} = $c_ref->{AssignSoft_MSOriginateNum};
            }
            if ( exists $c_ref->{CMO_PageResponceNum} ) {
                $c_ref->{CMO_PageResponceNum_Voice_Nbr} = $c_ref->{CMO_PageResponceNum};
            }
            if ( exists $c_ref->{AssignSoft_PageResponceNum} ) {
                $c_ref->{AssignSoft_PageResponceNum_Voice_Nbr} = $c_ref->{AssignSoft_PageResponceNum};
            }
                       
            return 0;
        },
    },    
    

    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for Cell_Voice_Overview_1X',
        INPUT_FILE_DESCRIPTION                    => [
            '(.*)1X_Cell_Voice_Originating_Call-#-I-#-PZ\.pif',
            '(.*)1X_Cell_Voice_Paging-#-I-#-PZ\.pif'
        ],
        OUTPUT_BLOCK_NAME                         => 'Cell_Voice_Overview_1X',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId BtsId CellId CarrierId)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 0,
        OUTPUT_FILENAME_START                     => 'Cell_Voice_Overview_1X',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        
    },

    
    {
        RULE_TYPE                 => 'AGGREGATE_LINE',
        RULE_DESC                 => 'Create Voice_call_number data counter by sum',
        INPUT_FILE_DESCRIPTION    => ['Cell_Voice_Overview_1X.*-#-J\.pif'],
        DEFAULT_NULL_VALUE        => '',
        COUNTER_GROUPS            => { Voice_call_number => '.*_Voice_Nbr', },
        OUTPUT_BLOCK_NAME         => 'Cell_Voice_Overview_1X',
        PRODUCE_LIF               => 'True',
        PRODUCE_PIF               => 'True',
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
    }, 
    
    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Rename data counters',
        INPUT_FILE_DESCRIPTION => [
            '.*DO_Cell_Common_Call-#-I\.pif'
        ],
        FILENAME_SUFFIX        => 'PZ',
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;
            if ( exists $c_ref->{CMO_CallTotalNum} ) {
                $c_ref->{CMO_CallTotalNum_Call_Nbr} = $c_ref->{CMO_CallTotalNum};
            }
            if ( exists $c_ref->{CMT_CallTotalNum} ) {
                $c_ref->{CMT_CallTotalNum_Call_Nbr} = $c_ref->{CMT_CallTotalNum};
            }
                       
            return 0;
        },
    },    
    
    
    {
        RULE_TYPE                 => 'AGGREGATE_LINE',
        RULE_DESC                 => 'Create Call_Number data counter by sum',
        INPUT_FILE_DESCRIPTION    => ['.*DO_Cell_Common_Call-#-I-#-PZ\.pif'],
        DEFAULT_NULL_VALUE        => '',
        COUNTER_GROUPS            => { Call_Number => '.*_Call_Nbr', },
        OUTPUT_BLOCK_NAME         => 'DO_Cell_Traffic_Overview',
        PRODUCE_LIF               => 'True',
        PRODUCE_PIF               => 'True',
        REDUNDANT_DATA_COUNTERS   => ['CMO_CallTotalNum_Call_Nbr', 'FMT_ExtInterruptNum', 'CMO_RFAccessFailureNum', 
        							  'CMT_CallSNum', 'CMT_RFAccessFailureNum', 'CMT_InvalidReqNum', 'FMT_CallTotalNum', 
        							  'FMT_CallSNum', 'FMT_RFAccessFailureNum', 'CMT_ExtInterruptNum', 'CMT_OtherFNum', 
        							  'FMT_OtherFNum', 'CMO_CallSNum', 'CMO_CallTotalNum', 'CMO_OtherFNum', 
        							  'CMT_CallTotalNum_Call_Nbr', 'CMO_ExtInterruptNum', 'CMT_BlockFNum', 'CMT_CallTotalNum', 
        							  'FMT_InvalidReqNum', 'CMO_InvalidReqNum', 'FMT_BlockFNum', 'CMO_BlockFNum' ],
    },    
        
    
    
    {
        RULE_TYPE                 => 'AGGREGATE_LINE',
        RULE_DESC                 => 'Create Cell_Broadcast_Call_Number data counter by sum',
        INPUT_FILE_DESCRIPTION    => ['.*PTT_Cell_Broadcast_Call-#-I\.pif'],
        DEFAULT_NULL_VALUE        => '',
        COUNTER_GROUPS            => { Cell_Broadcast_Call_Number => '.*Num', },
        OUTPUT_BLOCK_NAME         => 'PTT_Cell_Broadcast_traffic_overview',
        PRODUCE_LIF               => 'True',
        PRODUCE_PIF               => 'True',
        REDUNDANT_DATA_COUNTERS   => [ 'CellSetupSNum', 'CellSetupFNum' ],
    },                    

    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Rename data counters',
        INPUT_FILE_DESCRIPTION => [
            '.*PTT_Cell_Group_Call_Originating_Call-#-I\.pif',
            '.*PTT_Cell_Group_Call_Paging-#-I\.pif'
        ],
        FILENAME_SUFFIX        => 'PZ',
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;
            if ( exists $c_ref->{CMO_MSOriginateNum} ) {
                $c_ref->{CMO_MSOriginateNum_CellGrp_Nbr} = $c_ref->{CMO_MSOriginateNum};
            }
            if ( exists $c_ref->{AssignSoft_MSOriginateNum} ) {
                $c_ref->{AssignSoft_MSOriginateNum_CellGrp_Nbr} = $c_ref->{AssignSoft_MSOriginateNum};
            }
            if ( exists $c_ref->{AccProbe_MSOriginateNum} ) {
                $c_ref->{AccProbe_MSOriginateNum_CellGrp_Nbr} = $c_ref->{AccProbe_MSOriginateNum};
            }
            if ( exists $c_ref->{AccHo_MSOriginateNum} ) {
                $c_ref->{AccHo_MSOriginateNum_CellGrp_Nbr} = $c_ref->{AccHo_MSOriginateNum};
            }
            if ( exists $c_ref->{CMO_PageResponceNum} ) {
                $c_ref->{CMO_PageResponceNum_CellGrp_Nbr} = $c_ref->{CMO_PageResponceNum};
            }
            if ( exists $c_ref->{AssignSoft_PageResponceNum} ) {
                $c_ref->{AssignSoft_PageResponceNum_CellGrp_Nbr} = $c_ref->{AssignSoft_PageResponceNum};
            }
            if ( exists $c_ref->{AccProbe_PageResponceNum} ) {
                $c_ref->{AccProbe_PageResponceNum_CellGrp_Nbr} = $c_ref->{AccProbe_PageResponceNum};
            }
            if ( exists $c_ref->{AccHo_PageResponceNum} ) {
                $c_ref->{AccHo_PageResponceNum_CellGrp_Nbr} = $c_ref->{AccHo_PageResponceNum};
            }            
                       
            return 0;
        },
    },    
    

    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for PTT_Cell_group_traffic_overview',
        INPUT_FILE_DESCRIPTION                    => [
            '(.*)PTT_Cell_Group_Call_Originating_Call-#-I-#-PZ\.pif',
            '(.*)PTT_Cell_Group_Call_Paging-#-I-#-PZ\.pif'
        ],
        OUTPUT_BLOCK_NAME                         => 'PTT_Cell_group_traffic_overview',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId BtsId CellId CarrierId)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 0,
        OUTPUT_FILENAME_START                     => 'PTT_Cell_group_traffic_overview',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        
    },

    
    {
        RULE_TYPE                 => 'AGGREGATE_LINE',
        RULE_DESC                 => 'Create Cell_Group_call_number data counter by sum',
        INPUT_FILE_DESCRIPTION    => ['PTT_Cell_group_traffic_overview.*-#-J\.pif'],
        DEFAULT_NULL_VALUE        => '',
        COUNTER_GROUPS            => { Cell_Group_call_number => '.*_CellGrp_Nbr', },
        OUTPUT_BLOCK_NAME         => 'PTT_Cell_group_traffic_overview',
        PRODUCE_LIF               => 'True',
        PRODUCE_PIF               => 'True',
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
    },    
    
    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Rename data counters',
        INPUT_FILE_DESCRIPTION => [
            '.*PTT_Cell_Private_Call_Originating_Call-#-I\.pif',
            '.*PTT_Cell_Private_Call_Paging-#-I\.pif'
        ],
        FILENAME_SUFFIX        => 'PZ',
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;
            if ( exists $c_ref->{CMO_MSOriginateNum} ) {
                $c_ref->{CMO_MSOriginateNum_CellPrv_Nbr} = $c_ref->{CMO_MSOriginateNum};
            }
            if ( exists $c_ref->{AssignSoft_MSOriginateNum} ) {
                $c_ref->{AssignSoft_MSOriginateNum_CellPrv_Nbr} = $c_ref->{AssignSoft_MSOriginateNum};
            }
            if ( exists $c_ref->{AccProbe_MSOriginateNum} ) {
                $c_ref->{AccProbe_MSOriginateNum_CellPrv_Nbr} = $c_ref->{AccProbe_MSOriginateNum};
            }
            if ( exists $c_ref->{AccHo_MSOriginateNum} ) {
                $c_ref->{AccHo_MSOriginateNum_CellPrv_Nbr} = $c_ref->{AccHo_MSOriginateNum};
            }
            if ( exists $c_ref->{CMO_PageResponceNum} ) {
                $c_ref->{CMO_PageResponceNum_CellPrv_Nbr} = $c_ref->{CMO_PageResponceNum};
            }
            if ( exists $c_ref->{AssignSoft_PageResponceNum} ) {
                $c_ref->{AssignSoft_PageResponceNum_CellPrv_Nbr} = $c_ref->{AssignSoft_PageResponceNum};
            }
            if ( exists $c_ref->{AccProbe_PageResponceNum} ) {
                $c_ref->{AccProbe_PageResponceNum_CellPrv_Nbr} = $c_ref->{AccProbe_PageResponceNum};
            }
            if ( exists $c_ref->{AccHo_PageResponceNum} ) {
                $c_ref->{AccHo_PageResponceNum_CellPrv_Nbr} = $c_ref->{AccHo_PageResponceNum};
            }            
                       
            return 0;
        },
    },    
    

    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for PTT_Cell_private_traffic_overview',
        INPUT_FILE_DESCRIPTION                    => [
            '(.*)PTT_Cell_Private_Call_Originating_Call-#-I-#-PZ\.pif',
            '(.*)PTT_Cell_Private_Call_Paging-#-I-#-PZ\.pif'
        ],
        OUTPUT_BLOCK_NAME                         => 'PTT_Cell_private_traffic_overview',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId BtsId CellId CarrierId)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 0,
        OUTPUT_FILENAME_START                     => 'PTT_Cell_private_traffic_overview',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        
    },

    
    {
        RULE_TYPE                 => 'AGGREGATE_LINE',
        RULE_DESC                 => 'Create Cell_Private_call_number data counter by sum',
        INPUT_FILE_DESCRIPTION    => ['PTT_Cell_private_traffic_overview.*-#-J\.pif'],
        DEFAULT_NULL_VALUE        => '',
        COUNTER_GROUPS            => { Cell_Private_call_number => '.*_CellPrv_Nbr', },
        OUTPUT_BLOCK_NAME         => 'PTT_Cell_private_traffic_overview',
        PRODUCE_LIF               => 'True',
        PRODUCE_PIF               => 'True',
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
    },
    
    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Rename data counters',
        INPUT_FILE_DESCRIPTION => [
            '.*1X_Global_Concurrent_Voice_Originating_Call-#-I\.pif'
        ],
        FILENAME_SUFFIX        => 'PZ',
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;
            if ( exists $c_ref->{MSOriginateNum} ) {
                $c_ref->{Voice_call_number} = $c_ref->{MSOriginateNum};
            }            
                       
            return 0;
        },

    },    
    
    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Rename data counters',
        INPUT_FILE_DESCRIPTION => [
            '.*1X_Global_Concurrent_Packet_Originating_Call-#-I\.pif',
            '.*1X_Global_Concurrent_Packet_Paging-#-I\.pif'
        ],
        FILENAME_SUFFIX        => 'PZ',
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;
            if ( exists $c_ref->{MSOriginateNum} ) {
                $c_ref->{MSOriginateNum_Packet_Nbr} = $c_ref->{MSOriginateNum};
            }
            if ( exists $c_ref->{PageResponceNum} ) {
                $c_ref->{PageResponceNum_Packet_Nbr} = $c_ref->{PageResponceNum};
            }            
                       
            return 0;
        },

    },        
                
    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for Global_Concurrent_Overview_1X',
        INPUT_FILE_DESCRIPTION                    => [
            '(.*)1X_Global_Concurrent_Voice_Originating_Call-#-I-#-PZ\.pif',
            '(.*)1X_Global_Concurrent_Packet_Originating_Call-#-I-#-PZ\.pif',
            '(.*)1X_Global_Concurrent_Packet_Paging-#-I-#-PZ\.pif'
        ],
        OUTPUT_BLOCK_NAME                         => 'Global_Concurrent_Overview_1X',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId CarrierId)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 0,
        OUTPUT_FILENAME_START                     => 'Global_Concurrent_Overview_1X',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        
    },

    
    {
        RULE_TYPE                 => 'AGGREGATE_LINE',
        RULE_DESC                 => 'Create Packet_call_number data counter by sum',
        INPUT_FILE_DESCRIPTION    => ['Global_Concurrent_Overview_1X.*-#-J\.pif'],
        DEFAULT_NULL_VALUE        => '',
        COUNTER_GROUPS            => { Packet_call_number => '.*_Packet_Nbr', },
        OUTPUT_BLOCK_NAME         => 'Global_Concurrent_Overview_1X',
        PRODUCE_LIF               => 'True',
        PRODUCE_PIF               => 'True',
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
    },    
    
    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Rename data counters',
        INPUT_FILE_DESCRIPTION => [
            '.*1X_Global_Packet_Originating_Call-#-I\.pif',
            '.*1X_Global_Packet_Paging-#-I\.pif'
        ],
        FILENAME_SUFFIX        => 'PZ',
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;
            if ( exists $c_ref->{CMO_MSOriginateNum} ) {
                $c_ref->{CMO_MSOriginateNum_Packet_Nbr} = $c_ref->{CMO_MSOriginateNum};
            }
            if ( exists $c_ref->{AssignSoft_MSOriginateNum} ) {
                $c_ref->{AssignSoft_MSOriginateNum_Packet_Nbr} = $c_ref->{AssignSoft_MSOriginateNum};
            }
            if ( exists $c_ref->{CMO_PageResponceNum} ) {
                $c_ref->{CMO_PageResponceNum_Packet_Nbr} = $c_ref->{CMO_PageResponceNum};
            }
            if ( exists $c_ref->{AssignSoft_PageResponceNum} ) {
                $c_ref->{AssignSoft_PageResponceNum_Packet_Nbr} = $c_ref->{AssignSoft_PageResponceNum};
            }
                       
            return 0;
        },
    },    
    

    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for Global_Packet_Overview_1X',
        INPUT_FILE_DESCRIPTION                    => [
            '(.*)1X_Global_Packet_Originating_Call-#-I-#-PZ\.pif',
            '(.*)1X_Global_Packet_Paging-#-I-#-PZ\.pif'
        ],
        OUTPUT_BLOCK_NAME                         => 'Global_Packet_Overview_1X',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId CarrierId)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 0,
        OUTPUT_FILENAME_START                     => 'Global_Packet_Overview_1X',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        
    },

    
    {
        RULE_TYPE                 => 'AGGREGATE_LINE',
        RULE_DESC                 => 'Create Packet_call_number data counter by sum',
        INPUT_FILE_DESCRIPTION    => ['Global_Packet_Overview_1X.*-#-J\.pif'],
        DEFAULT_NULL_VALUE        => '',
        COUNTER_GROUPS            => { Packet_call_number => '.*_Packet_Nbr', },
        OUTPUT_BLOCK_NAME         => 'Global_Packet_Overview_1X',
        PRODUCE_LIF               => 'True',
        PRODUCE_PIF               => 'True',
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
    }, 
        
    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Rename data counters',
        INPUT_FILE_DESCRIPTION => [
            '.*1X_Global_SMS_Originating_Call_on_TCH-#-I\.pif',
            '.*1X_Global_SMS_Paging_on_TCH-#-I\.pif'
        ],
        FILENAME_SUFFIX        => 'PZ',
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;
            if ( exists $c_ref->{CMO_MSOrigNum} ) {
                $c_ref->{CMO_MSOrigNum_SMS_Nbr} = $c_ref->{CMO_MSOrigNum};
            }
            if ( exists $c_ref->{AssignSoft_MSOrigNum} ) {
                $c_ref->{AssignSoft_MSOrigNum_SMS_Nbr} = $c_ref->{AssignSoft_MSOrigNum};
            }
            if ( exists $c_ref->{AccProbe_MSOrigNum} ) {
                $c_ref->{AccProbe_MSOrigNum_SMS_Nbr} = $c_ref->{AccProbe_MSOrigNum};
            }
            if ( exists $c_ref->{AccHo_MSOrigNum} ) {
                $c_ref->{AccHo_MSOrigNum_SMS_Nbr} = $c_ref->{AccHo_MSOrigNum};
            }
            if ( exists $c_ref->{CMO_PageResponceNum} ) {
                $c_ref->{CMO_PageResponceNum_SMS_Nbr} = $c_ref->{CMO_PageResponceNum};
            }
            if ( exists $c_ref->{AssignSoft_PageResponceNum} ) {
                $c_ref->{AssignSoft_PageResponceNum_SMS_Nbr} = $c_ref->{AssignSoft_PageResponceNum};
            }
            if ( exists $c_ref->{AccProbe_PageResponceNum} ) {
                $c_ref->{AccProbe_PageResponceNum_SMS_Nbr} = $c_ref->{AccProbe_PageResponceNum};
            }
            if ( exists $c_ref->{AccHo_PageResponceNum} ) {
                $c_ref->{AccHo_PageResponceNum_SMS_Nbr} = $c_ref->{AccHo_PageResponceNum};
            }            
                       
            return 0;
        },
    },    
    

    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for Global_SMS_Overview_1X',
        INPUT_FILE_DESCRIPTION                    => [
            '(.*)1X_Global_SMS_Originating_Call_on_TCH-#-I-#-PZ\.pif',
            '(.*)1X_Global_SMS_Paging_on_TCH-#-I-#-PZ\.pif'
        ],
        OUTPUT_BLOCK_NAME                         => 'Global_SMS_Overview_1X',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId CarrierId)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 0,
        OUTPUT_FILENAME_START                     => 'Global_SMS_Overview_1X',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        
    },

    
    {
        RULE_TYPE                 => 'AGGREGATE_LINE',
        RULE_DESC                 => 'Create SMS_call_number data counter by sum',
        INPUT_FILE_DESCRIPTION    => ['Global_SMS_Overview_1X.*-#-J\.pif'],
        DEFAULT_NULL_VALUE        => '',
        COUNTER_GROUPS            => { SMS_call_number => '.*_SMS_Nbr', },
        OUTPUT_BLOCK_NAME         => 'Global_SMS_Overview_1X',
        PRODUCE_LIF               => 'True',
        PRODUCE_PIF               => 'True',
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
    },
    
    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Rename data counters',
        INPUT_FILE_DESCRIPTION => [
            '.*1X_Global_Voice_Originating_Call-#-I\.pif',
            '.*1X_Global_Voice_Paging-#-I\.pif'
        ],
        FILENAME_SUFFIX        => 'PZ',
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;
            if ( exists $c_ref->{CMO_MSOriginateNum} ) {
                $c_ref->{CMO_MSOriginateNum_Voice_Nbr} = $c_ref->{CMO_MSOriginateNum};
            }
            if ( exists $c_ref->{AssignSoft_MSOriginateNum} ) {
                $c_ref->{AssignSoft_MSOriginateNum_Voice_Nbr} = $c_ref->{AssignSoft_MSOriginateNum};
            }
            if ( exists $c_ref->{CMO_PageResponceNum} ) {
                $c_ref->{CMO_PageResponceNum_Voice_Nbr} = $c_ref->{CMO_PageResponceNum};
            }
            if ( exists $c_ref->{AssignSoft_PageResponceNum} ) {
                $c_ref->{AssignSoft_PageResponceNum_Voice_Nbr} = $c_ref->{AssignSoft_PageResponceNum};
            }
                       
            return 0;
        },
    },    
    

    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for Global_Voice_Overview_1X',
        INPUT_FILE_DESCRIPTION                    => [
            '(.*)1X_Global_Voice_Originating_Call-#-I-#-PZ\.pif',
            '(.*)1X_Global_Voice_Paging-#-I-#-PZ\.pif'
        ],
        OUTPUT_BLOCK_NAME                         => 'Global_Voice_Overview_1X',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId CarrierId)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 0,
        OUTPUT_FILENAME_START                     => 'Global_Voice_Overview_1X',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        
    },

    
    {
        RULE_TYPE                 => 'AGGREGATE_LINE',
        RULE_DESC                 => 'Create Voice_call_number data counter by sum',
        INPUT_FILE_DESCRIPTION    => ['Global_Voice_Overview_1X.*-#-J\.pif'],
        DEFAULT_NULL_VALUE        => '',
        COUNTER_GROUPS            => { Voice_call_number => '.*_Voice_Nbr', },
        OUTPUT_BLOCK_NAME         => 'Global_Voice_Overview_1X',
        PRODUCE_LIF               => 'True',
        PRODUCE_PIF               => 'True',
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
    }, 
    
    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Rename data counters',
        INPUT_FILE_DESCRIPTION => [
            '.*DO_Global_Common_Call-#-I\.pif'
        ],
        FILENAME_SUFFIX        => 'PZ',
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;
            if ( exists $c_ref->{CMO_CallTotalNum} ) {
                $c_ref->{CMO_CallTotalNum_Call_Nbr} = $c_ref->{CMO_CallTotalNum};
            }
            if ( exists $c_ref->{CMT_CallTotalNum} ) {
                $c_ref->{CMT_CallTotalNum_Call_Nbr} = $c_ref->{CMT_CallTotalNum};
            }
                       
            return 0;
        },
    },    
    
    
    {
        RULE_TYPE                 => 'AGGREGATE_LINE',
        RULE_DESC                 => 'Create Call_Number data counter by sum',
        INPUT_FILE_DESCRIPTION    => ['.*DO_Global_Common_Call-#-I-#-PZ\.pif'],
        DEFAULT_NULL_VALUE        => '',
        COUNTER_GROUPS            => { Call_Number => '.*_Call_Nbr', },
        OUTPUT_BLOCK_NAME         => 'DO_Global_Traffic_Overview',
        PRODUCE_LIF               => 'True',
        PRODUCE_PIF               => 'True',
        REDUNDANT_DATA_COUNTERS   => ['FMT_ExtInterruptNum', 'CMO_RFAccessFailureNum', 'CMT_CallSNum', 'CMT_RFAccessFailureNum', 
        					          'FMT_CallTotalNum', 'CMT_InvalidReqNum', 'FMT_RFAccessFailureNum', 'FMT_CallSNum', 
        					          'CMT_ExtInterruptNum', 'CMT_OtherFNum', 'FMT_OtherFNum', 'CMO_CallSNum', 'CMO_CallTotalNum', 
        					          'CMO_OtherFNum', 'CMO_ExtInterruptNum', 'CMT_BlockFNum', 'CMT_CallTotalNum', 'FMT_InvalidReqNum', 
        					          'CMO_InvalidReqNum', 'FMT_BlockFNum', 'CMO_BlockFNum', 'CMO_CallTotalNum_Call_Nbr', 'CMT_CallTotalNum_Call_Nbr' ],
    },    
    
    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Rename data counters',
        INPUT_FILE_DESCRIPTION => [
            '.*PTT_Global_Traditional_Broadcast_Call-#-I\.pif'
        ],
        FILENAME_SUFFIX        => 'PZ',
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;
            if ( exists $c_ref->{CallBSCSuccNum} ) {
                $c_ref->{CallBSCSuccNum_Glob_Nbr} = $c_ref->{CallBSCSuccNum};
            }
            if ( exists $c_ref->{CallBSCFailNum} ) {
                $c_ref->{CallBSCFailNum_Glob_Nbr} = $c_ref->{CallBSCFailNum};
            }
                       
            return 0;
        },
    },    
    
    
    {
        RULE_TYPE                 => 'AGGREGATE_LINE',
        RULE_DESC                 => 'Create Global_Broadcast_Call_Number data counter by sum',
        INPUT_FILE_DESCRIPTION    => ['.*PTT_Global_Traditional_Broadcast_Call-#-I-#-PZ\.pif'],
        DEFAULT_NULL_VALUE        => '',
        COUNTER_GROUPS            => { Global_Broadcast_Call_Number => '.*_Glob_Nbr', },
        OUTPUT_BLOCK_NAME         => 'PTT_Global_Broadcast_traffic_overview',
        PRODUCE_LIF               => 'True',
        PRODUCE_PIF               => 'True',
        REDUNDANT_DATA_COUNTERS   => ['NonCallBSCSuccNum', 'NonCallBSCFailNum', 'CallBSCFailNum_Glob_Nbr', 'CallBSCFailNum', 'CallBSCSuccNum', 'CallBSCSuccNum_Glob_Nbr' ],
    },    
        
    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Rename data counters',
        INPUT_FILE_DESCRIPTION => [
            '.*PTT_Global_Group_Call_Originating_Call-#-I\.pif',
            '.*PTT_Global_Group_Call_Paging-#-I\.pif'
        ],
        FILENAME_SUFFIX        => 'PZ',
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;
            if ( exists $c_ref->{CMO_MSOriginateNum} ) {
                $c_ref->{CMO_MSOriginateNum_Glob_Nbr} = $c_ref->{CMO_MSOriginateNum};
            }
            if ( exists $c_ref->{AssignSoft_MSOriginateNum} ) {
                $c_ref->{AssignSoft_MSOriginateNum_Glob_Nbr} = $c_ref->{AssignSoft_MSOriginateNum};
            }
            if ( exists $c_ref->{AccProbe_MSOriginateNum} ) {
                $c_ref->{AccProbe_MSOriginateNum_Glob_Nbr} = $c_ref->{AccProbe_MSOriginateNum};
            }
            if ( exists $c_ref->{AccHo_MSOriginateNum} ) {
                $c_ref->{AccHo_MSOriginateNum_Glob_Nbr} = $c_ref->{AccHo_MSOriginateNum};
            }
            if ( exists $c_ref->{CMO_PageResponceNum} ) {
                $c_ref->{CMO_PageResponceNum_Glob_Nbr} = $c_ref->{CMO_PageResponceNum};
            }
            if ( exists $c_ref->{AssignSoft_PageResponceNum} ) {
                $c_ref->{AssignSoft_PageResponceNum_Glob_Nbr} = $c_ref->{AssignSoft_PageResponceNum};
            }
            if ( exists $c_ref->{AccProbe_PageResponceNum} ) {
                $c_ref->{AccProbe_PageResponceNum_Glob_Nbr} = $c_ref->{AccProbe_PageResponceNum};
            }
            if ( exists $c_ref->{AccHo_PageResponceNum} ) {
                $c_ref->{AccHo_PageResponceNum_Glob_Nbr} = $c_ref->{AccHo_PageResponceNum};
            }            
                       
            return 0;
        },
    },    
    

    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for PTT_Global_group_traffic_overview',
        INPUT_FILE_DESCRIPTION                    => [
            '(.*)PTT_Global_Group_Call_Originating_Call-#-I-#-PZ\.pif',
            '(.*)PTT_Global_Group_Call_Paging-#-I-#-PZ\.pif'
        ],
        OUTPUT_BLOCK_NAME                         => 'PTT_Global_group_traffic_overview',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId CarrierId)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 0,
        OUTPUT_FILENAME_START                     => 'PTT_Global_group_traffic_overview',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        
    },

    
    {
        RULE_TYPE                 => 'AGGREGATE_LINE',
        RULE_DESC                 => 'Create Global_Group_call_number data counter by sum',
        INPUT_FILE_DESCRIPTION    => ['PTT_Global_group_traffic_overview.*-#-J\.pif'],
        DEFAULT_NULL_VALUE        => '',
        COUNTER_GROUPS            => { Global_Group_call_number => '.*_Glob_Nbr', },
        OUTPUT_BLOCK_NAME         => 'PTT_Global_group_traffic_overview',
        PRODUCE_LIF               => 'True',
        PRODUCE_PIF               => 'True',
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
    },
    
    {
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Rename data counters',
        INPUT_FILE_DESCRIPTION => [
            '.*PTT_Global_Private_Call_Originating_Call-#-I\.pif',
            '.*PTT_Global_Private_Call_Paging-#-I\.pif'
        ],
        FILENAME_SUFFIX        => 'PZ',
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;
            if ( exists $c_ref->{CMO_MSOriginateNum} ) {
                $c_ref->{CMO_MSOriginateNum_Glob_Nbr} = $c_ref->{CMO_MSOriginateNum};
            }
            if ( exists $c_ref->{AssignSoft_MSOriginateNum} ) {
                $c_ref->{AssignSoft_MSOriginateNum_Glob_Nbr} = $c_ref->{AssignSoft_MSOriginateNum};
            }
            if ( exists $c_ref->{AccProbe_MSOriginateNum} ) {
                $c_ref->{AccProbe_MSOriginateNum_Glob_Nbr} = $c_ref->{AccProbe_MSOriginateNum};
            }
            if ( exists $c_ref->{AccHo_MSOriginateNum} ) {
                $c_ref->{AccHo_MSOriginateNum_Glob_Nbr} = $c_ref->{AccHo_MSOriginateNum};
            }
            if ( exists $c_ref->{CMO_PageResponceNum} ) {
                $c_ref->{CMO_PageResponceNum_Glob_Nbr} = $c_ref->{CMO_PageResponceNum};
            }
            if ( exists $c_ref->{AssignSoft_PageResponceNum} ) {
                $c_ref->{AssignSoft_PageResponceNum_Glob_Nbr} = $c_ref->{AssignSoft_PageResponceNum};
            }
            if ( exists $c_ref->{AccProbe_PageResponceNum} ) {
                $c_ref->{AccProbe_PageResponceNum_Glob_Nbr} = $c_ref->{AccProbe_PageResponceNum};
            }
            if ( exists $c_ref->{AccHo_PageResponceNum} ) {
                $c_ref->{AccHo_PageResponceNum_Glob_Nbr} = $c_ref->{AccHo_PageResponceNum};
            }            
                       
            return 0;
        },
    },    
    

    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for PTT_Global_private_traffic_overview',
        INPUT_FILE_DESCRIPTION                    => [
            '(.*)PTT_Global_Private_Call_Originating_Call-#-I-#-PZ\.pif',
            '(.*)PTT_Global_Private_Call_Paging-#-I-#-PZ\.pif'
        ],
        OUTPUT_BLOCK_NAME                         => 'PTT_Global_private_traffic_overview',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId CarrierId)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 0,
        OUTPUT_FILENAME_START                     => 'PTT_Global_private_traffic_overview',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        
    },

    
    {
        RULE_TYPE                 => 'AGGREGATE_LINE',
        RULE_DESC                 => 'Create Global_Private_call_number data counter by sum',
        INPUT_FILE_DESCRIPTION    => ['PTT_Global_private_traffic_overview.*-#-J\.pif'],
        DEFAULT_NULL_VALUE        => '',
        COUNTER_GROUPS            => { Global_Private_call_number => '.*_Glob_Nbr', },
        OUTPUT_BLOCK_NAME         => 'PTT_Global_private_traffic_overview',
        PRODUCE_LIF               => 'True',
        PRODUCE_PIF               => 'True',
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
    },    
    
    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for CBSSB_Config',
        INPUT_FILE_DESCRIPTION                    => [
            '(.*)DO_Abis_Data_Flux-#-I\.pif',
            '(.*)DO_Global_Paging_Response-#-I\.pif',
            '(.*)DO_Global_Session_Authentication-#-I\.pif',
            '(.*)DO_Global_Session_Handoff-#-I\.pif',
            '(.*)DO_Global_Session_Negotiation-#-I\.pif',
            '(.*)DO_Global_Session_Setup-#-I\.pif',
            '(.*)1X_Global_SMS-#-I\.pif',
            '(.*)1X_No.7_Signal_Data_Flow_Stat-#-I\.pif',
            '(.*)PUB_PCF_Mac_Flux_Stat-#-I\.pif',
            '(.*)1X_RLP_Data_Flux-#-I\.pif'
        ],
        OUTPUT_BLOCK_NAME                         => 'CBSSB_Config',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId)],
        PRODUCE_PIF                               => 'True',
        OUTPUT_FILENAME_START                     => 'CBSSB_Config',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        REDUNDANT_DATA_COUNTERS                   => ['BscToBtsDataSize', 'BtsToBscDataSize', 'dwTxRexmitFrame', 'SndMessageSize', 'dwRxTotalFrame', 'RcvMessageSize', 'dwTxTotalFrame', 'dwRxRexmitFrame'],
        REDUNDANT_DATA_DESCRIPTION                => ['.*Num'],
        
    }, 
    
    {
        RULE_TYPE                                   => 'INFOINSERT',
        RULE_DESC                                   => 'INFOINSERT to include CellNum,BadCellNum,BusyCellNum in Block CBSSB_Config',
        INPUT_FILE_DESCRIPTION                      => ['CBSSB_Config-(.*)-J\.pif'],
        HEADER_NAMES_USED_TO_ID_DATA_RECORD         => [],
        NAMES_USED_TO_ID_DATA_RECORD                => ['ServerId','BssId'],
        INFO_FILE_DESCRIPTION                       => 'CBSSB_Config\.csv-#-I\.pif$',
        HEADER_NAMES_USED_TO_ID_INFORMATION         => [],
        NAMES_USED_TO_ID_INFORMATION                => ['ServerId','BssId'],
        REDUNDANT_DATA_COUNTERS                     => [],
        ONLY_INSERT                                 => ['CellNum', 'BadCellNum','BusyCellNum','numCE'],
        REMOVE_INFO_FILES                           => 'True',
        WRITE_DATA_LINE                             => 'True',
        PRODUCE_PIF                                 => 'True',
        OUTPUT_FORMAT                               => 'LIF_Writer',
    },

    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for CBSSB_Carrier_Config',
        INPUT_FILE_DESCRIPTION                    => [
														'(.*)1X_Global_Concurrent_ERL-#-I\.pif',
														'(.*)1X_Global_Concurrent_Packet_Originating_Call-#-I\.pif',
														'(.*)1X_Global_Concurrent_Packet_Paging-#-I\.pif',
														'(.*)1X_Global_Concurrent_Release-#-I\.pif',
														'(.*)1X_Global_Concurrent_Voice_Originating_Call-#-I\.pif',
														'(.*)1X_Global_Concurrent_Voice_Paging-#-I\.pif',
														'(.*)1X_Global_Hard_Handoff_Add_as_target_BSS-#-I\.pif',
														'(.*)1X_Global_Hard_Handoff_Drop_as_source_BSS-#-I\.pif',
														'(.*)1X_Global_Packet_ERL_BSSAP_part-#-I\.pif',
														'(.*)1X_Global_Packet_ERL_L3_part-#-I\.pif',
														'(.*)1X_Global_Packet_Handoff_as_target_BSS-#-I\.pif',
														'(.*)1X_Global_Packet_Handoff_intra_BSS-#-I\.pif',
														'(.*)1X_Global_Packet_Originating_Call-#-I\.pif',
														'(.*)1X_Global_Packet_Originating_Call_BSSAP_extended_part-#-I\.pif',
														'(.*)1X_Global_Packet_Paging-#-I\.pif',
														'(.*)1X_Global_Packet_Paging_BSSAP_extended_part-#-I\.pif',
														'(.*)1X_Global_Packet_Release-#-I\.pif',
														'(.*)1X_Global_Registration-#-I\.pif',
														'(.*)1X_Global_SMS_Block_Reason_BSSAP_part-#-I\.pif',
														'(.*)1X_Global_SMS_Block_Reason_L3_part-#-I\.pif',
														'(.*)1X_Global_SMS_ERL_BSSAP_part-#-I\.pif',
														'(.*)1X_Global_SMS_ERL_L3_part-#-I\.pif',
														'(.*)1X_Global_SMS_Originating_Call_BSSAP_extended_part-#-I\.pif',
														'(.*)1X_Global_SMS_Originating_Call_on_TCH-#-I\.pif',
														'(.*)1X_Global_SMS_Paging_BSSAP_extended_part-#-I\.pif',
														'(.*)1X_Global_SMS_Paging_on_TCH-#-I\.pif',
														'(.*)1X_Global_SMS_Release_on_TCH-#-I\.pif',
														'(.*)1X_Global_User_ExtInterrupt_Info-#-I\.pif',
														'(.*)1X_Global_User_ExtInterrupt_Info_Extended_part-#-I\.pif',
														'(.*)1X_Global_Voice_ERL_BSSAP_part-#-I\.pif',
														'(.*)1X_Global_Voice_ERL_L3_part-#-I\.pif',
														'(.*)1X_Global_Voice_Handoff_as_target_BSS-#-I\.pif',
														'(.*)1X_Global_Voice_Handoff_ERL_as_target_BSS-#-I\.pif',
														'(.*)1X_Global_Voice_Handoff_intra_BSS-#-I\.pif',
														'(.*)1X_Global_Voice_Originating_Call-#-I\.pif',
														'(.*)1X_Global_Voice_Originating_Call_BSSAP_extended_part-#-I\.pif',
														'(.*)1X_Global_Voice_Paging-#-I\.pif',
														'(.*)1X_Global_Voice_Paging_BSSAP_extended_part-#-I\.pif',
														'(.*)1X_Global_Voice_Release-#-I\.pif',
														'(.*)DO_Global_Assign_Soft_Call-#-I\.pif',
														'(.*)DO_Global_Common_Call-#-I\.pif',
														'(.*)DO_Global_Handoff_As_Target_AN-#-I\.pif',
														'(.*)DO_Global_Handoff_Intra_AN-#-I\.pif',
														'(.*)DO_Global_Hard_Handoff-#-I\.pif',
														'(.*)DO_Global_Release-#-I\.pif',
														'(.*)DO_Global_Virtual_Handoff-#-I\.pif',
														'(.*)PTT_Global_Group_Call_ERL_BSSAP_part-#-I\.pif',
														'(.*)PTT_Global_Group_Call_ERL_L3_part-#-I\.pif',
														'(.*)PTT_Global_Group_Call_Handoff_as_target_BSS-#-I\.pif',
														'(.*)PTT_Global_Group_Call_Handoff_ERL_as_target_BSS-#-I\.pif',
														'(.*)PTT_Global_Group_Call_Handoff_intra_BSS-#-I\.pif',
														'(.*)PTT_Global_Group_Call_Originating_Call-#-I\.pif',
														'(.*)PTT_Global_Group_Call_Paging-#-I\.pif',
														'(.*)PTT_Global_Group_Call_Release-#-I\.pif',
														'(.*)PTT_Global_Hard_Handoff_Add_as_target_BSS-#-I\.pif',
														'(.*)PTT_Global_Hard_Handoff_Drop_as_source_BSS-#-I\.pif',
														'(.*)PTT_Global_Private_Call_ERL_BSSAP_part-#-I\.pif',
														'(.*)PTT_Global_Private_Call_ERL_L3_part-#-I\.pif',
														'(.*)PTT_Global_Private_Call_Handoff_as_target_BSS-#-I\.pif',
														'(.*)PTT_Global_Private_Call_Handoff_ERL_as_target_BSS-#-I\.pif',
														'(.*)PTT_Global_Private_Call_Handoff_intra_BSS-#-I\.pif',
														'(.*)PTT_Global_Private_Call_Originating_Call-#-I\.pif',
														'(.*)PTT_Global_Private_Call_Paging-#-I\.pif',
														'(.*)PTT_Global_Private_Call_Release-#-I\.pif',
														'(.*)PTT_Global_Registration-#-I\.pif',
														'(.*)PTT_Global_Source_BSC_Handoff-#-I\.pif',
														'Global_Concurrent_Overview_1X-#-(.*)\d+-#-J-#-AL\.pif',
														'Global_Packet_Overview_1X-#-(.*)\d+-#-J-#-AL\.pif',
														'Global_SMS_Overview_1X-#-(.*)\d+-#-J-#-AL\.pif',
														'Global_Voice_Overview_1X-#-(.*)\d+-#-J-#-AL\.pif',
														'(.*)PTT_Global_Traditional_Broadcast_Call-#-I-#-PZ-#-AL\.pif',
														'PTT_Global_group_traffic_overview-#-(.*)\d+-#-J-#-AL\.pif',
														'PTT_Global_private_traffic_overview-#-(.*)\d+-#-J-#-AL\.pif'
														
        											],
        OUTPUT_BLOCK_NAME                         => 'CBSSB_Carrier_Config',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId CarrierId)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 'True',
        OUTPUT_FILENAME_START                     => 'CBSSB_Carrier_Config',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
        
    },
    
    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for CBSSB_BTS_Config',
        INPUT_FILE_DESCRIPTION                    => [
														'(.*)1X_BTS_95_CE-#-I\.pif',
														'(.*)1X_BTS_FCE-#-I\.pif',
														'(.*)1X_BTS_RCE-#-I\.pif',
														'(.*)DO_BTS_CHM1_CE-#-I\.pif',
														'(.*)DO_BTS_CHM2_CE-#-I\.pif'
        											],
        OUTPUT_BLOCK_NAME                         => 'CBSSB_BTS_Config',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId BtsId)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 'True',
        OUTPUT_FILENAME_START                     => 'CBSSB_BTS_Config',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
        
    },    
        
    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for CBSSB_Cell_Carrier_Config',
        INPUT_FILE_DESCRIPTION                    => [
														'(.*)1X_Cell_Concurrent_ERL-#-I\.pif',
														'(.*)1X_Cell_Concurrent_Packet_Originating_Call-#-I\.pif',
														'(.*)1X_Cell_Concurrent_Packet_Paging-#-I\.pif',
														'(.*)1X_Cell_Concurrent_Release-#-I\.pif',
														'(.*)1X_Cell_Concurrent_Voice_Originating_Call-#-I\.pif',
														'(.*)1X_Cell_Concurrent_Voice_Paging-#-I\.pif',
														'(.*)1X_Cell_FSCH_Setup_intra_BSS-#-I\.pif',
														'(.*)1X_Cell_FSCH_Setup_as_target_BSS-#-I\.pif',
														'(.*)1X_Cell_Hard_Handoff_Add_as_target_BSS-#-I\.pif',
														'(.*)1X_Cell_Hard_Handoff_Drop_as_source_BSS-#-I\.pif',
														'(.*)1X_Cell_Packet_ERL_BSSAP_part-#-I\.pif',
														'(.*)1X_Cell_Packet_ERL_L3_part-#-I\.pif',
														'(.*)1X_Cell_Packet_Flux-#-I\.pif',
														'(.*)1X_Cell_Packet_Handoff_ERL_as_target_BSS-#-I\.pif',
														'(.*)1X_Cell_Packet_Handoff_intra_BSS-#-I\.pif',
														'(.*)1X_Cell_Packet_Handoff_as_target_BSS-#-I\.pif',
														'(.*)1X_Cell_Packet_Originating_Call-#-I\.pif',
														'(.*)1X_Cell_Packet_Originating_Call_BSSAP_extended_part-#-I\.pif',
														'(.*)1X_Cell_Packet_Paging-#-I\.pif',
														'(.*)1X_Cell_Packet_Paging_BSSAP_extended_part-#-I\.pif',
														'(.*)1X_Cell_Packet_Release-#-I\.pif',
														'(.*)1X_Cell_RC_Call-#-I\.pif',
														'(.*)1X_Cell_Registration-#-I\.pif',
														'(.*)1X_Cell_RSCH_Setup_intra_BSS-#-I\.pif',
														'(.*)1X_Cell_RSCH_Setup_as_target_BSS-#-I\.pif',
														'(.*)1X_Cell_SMS_Block_Reason_BSSAP_part-#-I\.pif',
														'(.*)1X_Cell_SMS_Block_Reason_L3_part-#-I\.pif',
														'(.*)1X_Cell_SMS_ERL_BSSAP_part-#-I\.pif',
														'(.*)1X_Cell_SMS_ERL_L3_part-#-I\.pif',
														'(.*)1X_Cell_SMS_Originating_Call_BSSAP_extended_part-#-I\.pif',
														'(.*)1X_Cell_SMS_Originating_Call_on_TCH-#-I\.pif',
														'(.*)1X_Cell_SMS_Paging_BSSAP_extended_part-#-I\.pif',
														'(.*)1X_Cell_SMS_Paging_on_TCH-#-I\.pif',
														'(.*)1X_Cell_SMS_Release_on_TCH-#-I\.pif',
														'(.*)1X_Cell_User_ExtInterrupt_Info-#-I\.pif',
														'(.*)1X_Cell_User_ExtInterrupt_Info_Extended_part-#-I\.pif',
														'(.*)1X_Cell_Voice_ERL_BSSAP_part-#-I\.pif',
														'(.*)1X_Cell_Voice_ERL_L3_part-#-I\.pif',
														'(.*)1X_Cell_Voice_Handoff_ERL_as_target_BSS-#-I\.pif',
														'(.*)1X_Cell_Voice_Handoff_intra_BSS-#-I\.pif',
														'(.*)1X_Cell_Voice_Handoff_as_target_BSS-#-I\.pif',
														'(.*)1X_Cell_Voice_Originating_Call-#-I\.pif',
														'(.*)1X_Cell_Voice_Originating_Call_BSSAP_extended_part-#-I\.pif',
														'(.*)1X_Cell_Voice_Paging-#-I\.pif',
														'(.*)1X_Cell_Voice_Paging_BSSAP_extended_part-#-I\.pif',
														'(.*)1X_Cell_Voice_Release-#-I\.pif',
														'Cell_Concurrent_Overview_1X-#-(.*)\d+-#-J-#-AL\.pif',
														'Cell_Packet_Overview_1X-#-(.*)\d+-#-J-#-AL\.pif',
														'Cell_SMS_Overview_1X-#-(.*)\d+-#-J-#-AL\.pif',
														'Cell_Voice_Overview_1X-#-(.*)\d+-#-J-#-AL\.pif',
														'(.*)DO_Cell_Assign_Soft_Call-#-I\.pif',
														'(.*)DO_Cell_BSSAP_Call_Failure-#-I\.pif',
														'(.*)DO_Cell_Common_Call-#-I\.pif',
														'(.*)DO_Cell_FCH_ERL-#-I\.pif',
														'(.*)DO_Cell_Forward_Flux-#-I\.pif',
														'(.*)DO_Cell_Handoff_Intra_AN-#-I\.pif',
														'(.*)DO_Cell_Handoff_As_Target_AN-#-I\.pif',
														'(.*)DO_Cell_Hard_Handoff-#-I\.pif',
														'(.*)DO_Cell_Redirect-#-I\.pif',
														'(.*)DO_Cell_Release-#-I\.pif',
														'(.*)DO_Cell_Reverse_Flux-#-I\.pif',
														'(.*)DO_Cell_Reverse_Frame_Stat-#-I\.pif',
														'(.*)DO_Cell_RTD_info-#-I\.pif',
														'(.*)DO_Cell_Session_Setup-#-I\.pif',
														'(.*)DO_Cell_Traffic_Overview-#-I-#-PZ-#-AL\.pif',
														'(.*)DO_Cell_Virtual_Handoff-#-I\.pif',
														'(.*)PTT_Cell_Broadcast_Call-#-I\.pif',
														'(.*)PTT_Cell_Broadcast_ERL-#-I\.pif',
														'(.*)PTT_Cell_Broadcast_Release-#-I\.pif',
														'(.*)PTT_Cell_Broadcast_traffic_overview-#-I-#-AL\.pif',
														'(.*)PTT_Cell_Group_Call_Handoff_intra_BSS-#-I\.pif',
														'(.*)PTT_Cell_Group_Call_ERL_BSSAP_part-#-I\.pif',
														'(.*)PTT_Cell_Group_Call_Handoff_as_target_BSS-#-I\.pif',
														'(.*)PTT_Cell_Group_Call_Handoff_ERL_as_target_BSS-#-I\.pif',
														'(.*)PTT_Cell_Group_Call_Release-#-I\.pif',
														'(.*)PTT_Cell_Group_Call_ERL_L3_part-#-I\.pif',
														'(.*)PTT_Cell_Group_Call_Originating_Call-#-I\.pif',
														'(.*)PTT_Cell_Group_Call_Paging-#-I\.pif',
														'PTT_Cell_group_traffic_overview-#-(.*)\d+-#-J-#-AL\.pif',
														'(.*)PTT_Cell_Hard_Handoff_Add_as_target_BSS-#-I\.pif',
														'(.*)PTT_Cell_Hard_Handoff_Drop_as_source_BSS-#-I\.pif',
														'(.*)PTT_Cell_Private_Call_ERL_BSSAP_part-#-I\.pif',
														'(.*)PTT_Cell_Private_Call_Handoff_intra_BSS-#-I\.pif',
														'(.*)PTT_Cell_Private_Call_Handoff_as_target_BSS-#-I\.pif',
														'(.*)PTT_Cell_Private_Call_Handoff_ERL_as_target_BSS-#-I\.pif',
														'(.*)PTT_Cell_Private_Call_Release-#-I\.pif',
														'(.*)PTT_Cell_Private_Call_ERL_L3_part-#-I\.pif',
														'(.*)PTT_Cell_Private_Call_Originating_Call-#-I\.pif',
														'(.*)PTT_Cell_Private_Call_Paging-#-I\.pif',
														'PTT_Cell_private_traffic_overview-#-(.*)\d+-#-J-#-AL\.pif',
														'(.*)PTT_Cell_Registration-#-I\.pif',
        											],
        OUTPUT_BLOCK_NAME                         => 'CBSSB_Cell_Carrier_Config',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId BtsId CellId CarrierId)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 'True',
        OUTPUT_FILENAME_START                     => 'CBSSB_Cell_Carrier_Config',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
        
    },  
    
    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for CBSSB_Cell_Carrier_Service_Config',
        INPUT_FILE_DESCRIPTION                    => [
														'(.*)1X_Cell_Voice_Block_Reason_BSSAP-#-I\.pif',
														'(.*)1X_Cell_Packet_Block_Reason_BSSAP_part-#-I\.pif',
														'(.*)1X_Cell_Packet_Block_Reason_L3-#-I\.pif',
														'(.*)1X_Cell_Voice_Block_Reason_L3-#-I\.pif'
        											],
        OUTPUT_BLOCK_NAME                         => 'CBSSB_Cell_Carrier_Service_Config',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId BtsId CellId ServiceType CarrierId)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 'True',
        OUTPUT_FILENAME_START                     => 'CBSSB_Cell_Carrier_Service_Config',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
        
    },
    
    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for CBSSB_Cell_Subsystem_Carrier_Config',
        INPUT_FILE_DESCRIPTION                    => [
														'(.*)1X_Cell_CES_Link_Data-#-I\.pif',
														'(.*)DO_Cell_RLP_Info-#-I\.pif',
														'(.*)DO_Cell_CES_Link_Data-#-I\.pif',
														'(.*)DO_Cell_Overload-#-I\.pif',
														'(.*)1X_Forward_power_status_statistic-#-I\.pif',
														'(.*)1X_Traffic_Channel-#-I\.pif'
        											],
        OUTPUT_BLOCK_NAME                         => 'CBSSB_Cell_Subsystem_Carrier_Config',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId BtsId CellId SubsystemId CarrierId)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 'True',
        OUTPUT_FILENAME_START                     => 'CBSSB_Cell_Subsystem_Carrier_Config',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
        
    },                
    
    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for CBSSB_Module_Config',
        INPUT_FILE_DESCRIPTION                    => [
														'(.*)1X_CIC-#-I\.pif',
														'(.*)PUB_1XCMP_V5CMP_CPU_Usage-#-I\.pif',
														'(.*)1X_DSPM-#-I\.pif',
														'(.*)1X_Global_PCF_Block-#-I\.pif',
														'(.*)1X_Global_PCF_Call-#-I\.pif',
														'(.*)1X_Global_PCF_Entity-#-I\.pif',
														'(.*)1X_Global_PCF_Handoff-#-I\.pif',
														'(.*)1X_Global_PCF_Release-#-I\.pif',
														'(.*)1X_IP_VE-#-I\.pif',
														'(.*)1X_SE-#-I\.pif',
														'(.*)DO_Global_PCF_Block-#-I\.pif',
														'(.*)DO_Global_PCF_Call-#-I\.pif',
														'(.*)DO_Global_PCF_Entity-#-I\.pif',
														'(.*)DO_Global_PCF_Handoff-#-I\.pif',
														'(.*)DO_Global_PCF_Release-#-I\.pif',
														'(.*)DO_Global_Session_Duration-#-I\.pif',
														'(.*)DO_Global_Session_Setup_And_Connection-#-I\.pif',
														'(.*)DO_SE-#-I\.pif',
														'(.*)PUB_DOCMP_CPU_Usage-#-I\.pif',
														'(.*)PUB_DSMP_CPU_Usage-#-I\.pif',
														'(.*)PUB_OMP_CPU_Usage-#-I\.pif',
														'(.*)PUB_PCF_Media_Flux_Stat-#-I\.pif',
														'(.*)PUB_PCF_Signal_Flux_Stat-#-I\.pif',
														'(.*)PUB_RMP_CPU_Usage-#-I\.pif',
														'(.*)PUB_SPCF_CPU_Usage-#-I\.pif',
        											],
        OUTPUT_BLOCK_NAME                         => 'CBSSB_Module_Config',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId ModuleId)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 'True',
        OUTPUT_FILENAME_START                     => 'CBSSB_Module_Config',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
        
    },
    
    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for CBSSB_Subnet_Config',
        INPUT_FILE_DESCRIPTION                    => [
														'(.*)DO_Subnet_Session_Handoff-#-I\.pif',
														'(.*)DO_Subnet_Session_Negotiation-#-I\.pif',
														'(.*)DO_Subnet_Session_Release-#-I\.pif',
														'(.*)DO_Subnet_Session_Setup-#-I\.pif'
        											],
        OUTPUT_BLOCK_NAME                         => 'CBSSB_Subnet_Config',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId ColorCode)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 'True',
        OUTPUT_FILENAME_START                     => 'CBSSB_Subnet_Config',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
        
    },
    
    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for CBSSB_System_Cell_Carrier_Config',
        INPUT_FILE_DESCRIPTION                    => [
														'(.*)PUB_HIRS_ARIR_RF_Data-#-I\.pif',
														'(.*)PUB_HIRS_RFS_Data-#-I\.pif'
        											],
        OUTPUT_BLOCK_NAME                         => 'CBSSB_System_Cell_Carrier_Config',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId SystemId SubsystemId CellId CarrierId)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 'True',
        OUTPUT_FILENAME_START                     => 'CBSSB_System_Cell_Carrier_Config',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        REDUNDANT_DATA_COUNTERS => ['MaxRSSI_M_dBm', 'AvgTP_dBm', 'MinARIRRSSI_D_dBm', 'AvgARIRRSSI_M_dBm', 'MaxRSSI_D_dBm', 'AvgRSSI_M_dBm', 
        							'AvgARIRRSSI_D_dBm', 'MaxARIRRSSI_M_dBm', 'MinRSSI_M_dBm', 'MinTP_dBm', 'AvgRSSI_D_dBm', 'MaxTP_dBm', 
        							'MaxARIRRSSI_D_dBm', 'MinRSSI_D_dBm', 'MinARIRRSSI_M_dBm'],
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
        
    },
    
    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for CBSSB_System_SUnit_Config',
        INPUT_FILE_DESCRIPTION                    => [
														'(.*)PUB_CCM_CPU_Usage-#-I\.pif',
														'(.*)PUB_DOSDU_CPU_Usage-#-I\.pif'
        											],
        OUTPUT_BLOCK_NAME                         => 'CBSSB_System_SUnit_Config',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId SystemId SubsystemId UnitId SUNIT)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 'True',
        OUTPUT_FILENAME_START                     => 'CBSSB_System_SUnit_Config',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        REDUNDANT_DATA_COUNTERS => ['AvgUseRate', 'MaxUseRate'],
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
        
    },
    
    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for CBSSB_System_Unit_Carrier_Config',
        INPUT_FILE_DESCRIPTION                    => [
														'(.*)PUB_IP_ARIR_RF_Data-#-I\.pif',
														'(.*)PUB_IP_RFS_Data-#-I\.pif'
        											],
        OUTPUT_BLOCK_NAME                         => 'CBSSB_System_Unit_Carrier_Config',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId SystemId SubsystemId UnitId CellID CarrierId)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 'True',
        OUTPUT_FILENAME_START                     => 'CBSSB_System_Unit_Carrier_Config',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
        REDUNDANT_DATA_COUNTERS => ['AvgRSSIInstant_M', 'MaxRSSIInstant_D', 'MaxRSSIInstant_M', 'AvgForwardPower', 'MinForwardPower', 'MaxForwardPower', 'MinRSSIInstant_D', 'MinRSSIInstant_M', 'AvgRSSIInstant_D'],
    },
    
    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for CBSSB_System_Unit_CPU_Config',
        INPUT_FILE_DESCRIPTION                    => [
														'(.*)PUB_ABPM_CPU_Usage-#-I\.pif',
														'(.*)PUB_HGM_CPU_Usage-#-I\.pif'
        											],
        OUTPUT_BLOCK_NAME                         => 'CBSSB_System_Unit_CPU_Config',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId SystemId SubsystemId UnitId CPUType)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 'True',
        OUTPUT_FILENAME_START                     => 'CBSSB_System_Unit_CPU_Config',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        REDUNDANT_DATA_COUNTERS => ['AvgUseRate', 'MaxUseRate'],
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
        
    },
    
    {
        RULE_TYPE                                 => 'JOIN',
        RULE_DESC                                 => 'Join for CBSSB_Carrier_Service_Config',
        INPUT_FILE_DESCRIPTION                    => [
														'(.*)1X_Global_Voice_Block_Reason_BSSAP_part-#-I\.pif',
														'(.*)1X_Global_Voice_Block_Reason_L3-#-I\.pif',
														'(.*)1X_Global_Packet_Block_Reason_BSSAP-#-I\.pif',
														'(.*)1X_Global_Packet_Block_Reason_L3-#-I\.pif'
        											],
        OUTPUT_BLOCK_NAME                         => 'CBSSB_Carrier_Service_Config',
        COUNTERS_TO_JOIN_ON                       => [qw(NETWORK_ID REGION_ID ServerId BssId CarrierId ServiceType)],
        PRODUCE_PIF                               => 'True',
        PRODUCE_LIF                               => 'True',
        OUTPUT_FILENAME_START                     => 'CBSSB_Carrier_Service_Config',
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
        REDUNDANT_DATA_DESCRIPTION => ['.*Num'],
        
    },

	# ======================================================
	# Aggregate Cell_CES_Link_Data block to CBSSB_Cell level
	# ======================================================

	# Cell_Concurrent_ERL_1X.AvfSvcAss_AvfAssCmp_CallDur
	# Cell_Concurrent_ERL_1X.AvfSvcAss_AvfAssCmp_SHoDur
	# Cell_Concurrent_ERL_1X.AvfSvcAss_AvfAssCmp_SSHoDur
	# Cell_Concurrent_ERL_1X.AvrAssCmp_AvfRlsReq_CallDur
	# Cell_Concurrent_ERL_1X.AvrAssCmp_AvfRlsReq_ShoDur
	# Cell_Concurrent_ERL_1X.AvrAssCmp_AvfRlsReq_SSHoDur

	{
        RULE_TYPE               => 'ACCUMULATE',
        RULE_DESC               => 'Aggregate Cell_Concurrent_ERL_1X block to CBSSB_Cell level',
        INPUT_FILE_DESCRIPTION  => ['.*1X_Cell_Concurrent_ERL-#-I\.pif'],
        COUNTERS_TO_SORT_ON     => [qw(ServerId BssId BtsId CellId)],

        AVERAGE_COUNTERS        => [qw(AvfSvcAss_AvfAssCmp_CallDur AvfSvcAss_AvfAssCmp_SHoDur AvfSvcAss_AvfAssCmp_SSHoDur AvrAssCmp_AvfRlsReq_CallDur AvrAssCmp_AvfRlsReq_ShoDur AvrAssCmp_AvfRlsReq_SSHoDur)],
        AVERAGE_APPEND_STR      => "_AVG",
        AVERAGE_NO_APPEND_STR   => [qw(AvfSvcAss_AvfAssCmp_CallDur AvfSvcAss_AvfAssCmp_SHoDur AvfSvcAss_AvfAssCmp_SSHoDur AvrAssCmp_AvfRlsReq_CallDur AvrAssCmp_AvfRlsReq_ShoDur AvrAssCmp_AvfRlsReq_SSHoDur)],

        OUTPUT_BLOCK_NAME       => 'Cell_Concurrent_ERL_1X_AGGR_CELL',
        PRODUCE_LIF             => 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Average Cell_Packet_ERL_BSSAP_1X  block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_Packet_ERL_BSSAP_part-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_Packet_ERL_BSSAP_1X_AGGR_CELL',
		AVERAGE_COUNTERS		=> [qw(AvfAssReq_AvfSvcAss_CallDur)],
		AVERAGE_APPEND_STR		=> '_AVG',
        AVERAGE_NO_APPEND_STR	=> [qw(AvfAssReq_AvfSvcAss_CallDur)],
		PRODUCE_LIF				=> 'True',
				
	},

	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Average Cell_Packet_ERL_L3_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_Packet_ERL_L3_part-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_Packet_ERL_L3_1X_AGGR_CELL',
		AVERAGE_COUNTERS		=> [qw(AvfSvcAss_AvfAssCmp_CallDur AvfSvcAss_AvfAssCmp_SHoDur AvfSvcAss_AvfAssCmp_SSHoDur AvrAssCmp_AvfRlsReq_CallDur AvrAssCmp_AvfRlsReq_ShoDur AvrAssCmp_AvfRlsReq_SSHoDur)],
		AVERAGE_APPEND_STR		=> '_AVG',
		AVERAGE_NO_APPEND_STR	=> [qw(AvfSvcAss_AvfAssCmp_CallDur AvfSvcAss_AvfAssCmp_SHoDur AvfSvcAss_AvfAssCmp_SSHoDur AvrAssCmp_AvfRlsReq_CallDur AvrAssCmp_AvfRlsReq_ShoDur AvrAssCmp_AvfRlsReq_SSHoDur)],
		PRODUCE_LIF				=> 'True',
	},

    {
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Average Cell_SMS_ERL_BSSAP_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_SMS_ERL_BSSAP_part-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_SMS_ERL_BSSAP_1X_AGGR_CELL',
		AVERAGE_COUNTERS		=> [qw(AvfAssReq_AvfSvcAss_CallDur)],
		AVERAGE_APPEND_STR		=> '_AVG',
		AVERAGE_NO_APPEND_STR	=> [qw(AvfAssReq_AvfSvcAss_CallDur)],
		PRODUCE_LIF				=> 'True',
	},

    {
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Average Cell_SMS_ERL_L3_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_SMS_ERL_L3_part-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_SMS_ERL_L3_1X_AGGR_CELL',
		AVERAGE_COUNTERS		=> [qw(AvfSvcAss_AvfAssCmp_CallDur AvfSvcAss_AvfAssCmp_SHoDur AvfSvcAss_AvfAssCmp_SSHoDur AvrAssCmp_AvfRlsReq_CallDur AvrAssCmp_AvfRlsReq_ShoDur AvrAssCmp_AvfRlsReq_SSHoDur)],
		AVERAGE_APPEND_STR		=> '_AVG',
		AVERAGE_NO_APPEND_STR	=> [qw(AvfSvcAss_AvfAssCmp_CallDur AvfSvcAss_AvfAssCmp_SHoDur AvfSvcAss_AvfAssCmp_SSHoDur AvrAssCmp_AvfRlsReq_CallDur AvrAssCmp_AvfRlsReq_ShoDur AvrAssCmp_AvfRlsReq_SSHoDur)],
		PRODUCE_LIF				=> 'True',
	},

	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Average Cell_Voice_ERL_BSSAP_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_Voice_ERL_BSSAP_part-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_Voice_ERL_BSSAP_1X_AGGR_CELL',
		AVERAGE_COUNTERS		=> [qw(AvfAssReq_AvfSvcAss_CallDur)],
		AVERAGE_APPEND_STR		=> '_AVG',
		AVERAGE_NO_APPEND_STR	=> [qw(AvfAssReq_AvfSvcAss_CallDur)],
		PRODUCE_LIF				=> 'True',
	},
	
	    
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Average Cell_Voice_ERL_BSSAP_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_Voice_ERL_L3_part-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_Voice_ERL_L3_1X_AGGR_CELL',
		AVERAGE_APPEND_STR		=> '_AVG',
		AVERAGE_COUNTERS		=> [qw(AvfSvcAss_AvfAssCmp_CallDur AvfSvcAss_AvfAssCmp_SHoDur AvfSvcAss_AvfAssCmp_SSHoDur AvrAssCmp_AvfRlsReq_CallDur AvrAssCmp_AvfRlsReq_ShoDur AvrAssCmp_AvfRlsReq_SSHoDur)],
		AVERAGE_NO_APPEND_STR	=> [qw(AvfSvcAss_AvfAssCmp_CallDur AvfSvcAss_AvfAssCmp_SHoDur AvfSvcAss_AvfAssCmp_SSHoDur AvrAssCmp_AvfRlsReq_CallDur AvrAssCmp_AvfRlsReq_ShoDur AvrAssCmp_AvfRlsReq_SSHoDur)],
		PRODUCE_LIF				=> 'True',
	},


	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Average Cell_Voice_Handoff_ERL_TgtBSS_1X block to cBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_Voice_Handoff_ERL_as_target_BSS-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_Voice_Handoff_ERL_TgtBSS_1X_AGGR_CELL',
		AVERAGE_APPEND_STR		=> '_AVG',
		AVERAGE_COUNTERS		=> [qw(SHoDuration SSHoDuration)],
		AVERAGE_NO_APPEND_STR	=> [qw(SHoDuration SSHoDuration)],
		PRODUCE_LIF				=> 'True',
	},

	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Average DO_Cell_FCH_ERL block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*DO_Cell_FCH_ERL-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'DO_Cell_FCH_ERL_AGGR_CELL',
		AVERAGE_APPEND_STR		=> '_AVG',
		AVERAGE_COUNTERS		=> [qw(CallDuration SHoDuration SSHoDuration)],
		AVERAGE_NO_APPEND_STR	=> [qw(CallDuration SHoDuration SSHoDuration)],
		PRODUCE_LIF				=> 'True',
	},

	
	# ======================================================
	# SUM Cell_CES_Link_Data_1X block to CBSSB_Cell level
	# ======================================================
	#	Cell_CES_Link_Data_1X.BadFrmNum
	#	Cell_CES_Link_Data_1X.GoodFrmNum
    # ======================================================

    {
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Cell_CES_Link_Data_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_CES_Link_Data-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_CES_Link_Data_1X_AGGR_CELL',
		SUM_COUNTERS			=> [qw(BadFrmNum GoodFrmNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(BadFrmNum GoodFrmNum)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Cell_Concurrent_Packet_Originating_Call_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_Concurrent_Packet_Originating_Call-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_Concurrent_Packet_Originating_Call_1X_AGGR_CELL',
		SUM_COUNTERS			=> [qw(BlockFailureNum CallSuccessNum ExtInterruptNum OtherFailureNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(BlockFailureNum CallSuccessNum ExtInterruptNum OtherFailureNum)],
		PRODUCE_LIF				=> 'True',
	},

	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Cell_Concurrent_Packet_Paging_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_Concurrent_Packet_Paging-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_Concurrent_Packet_Paging_1X_AGGR_CELL',
		SUM_COUNTERS			=> [qw(BlockFailureNum CallSuccessNum ExtInterruptNum OtherFailureNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(BlockFailureNum CallSuccessNum ExtInterruptNum OtherFailureNum)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Cell_Concurrent_Release_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_Concurrent_Release-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_Concurrent_Release_1X_AGGR_CELL',
		SUM_COUNTERS			=> [qw(ConData_RlsFailNum ConData_RlsSuccNum ConVoc_RlsFailNum ConVoc_RlsSuccNum ConVocData_RlsFailNum ConVocData_RlsSuccNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(ConData_RlsFailNum ConData_RlsSuccNum ConVoc_RlsFailNum ConVoc_RlsSuccNum ConVocData_RlsFailNum ConVocData_RlsSuccNum)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Cell_Concurrent_Voice_Originating_Call_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=>['.*1X_Cell_Concurrent_Voice_Originating_Call-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_Concurrent_Voice_Originating_Call_1X_AGGR_CELL',
		SUM_COUNTERS			=> [qw(BlockFailureNum CallSuccessNum ExtInterruptNum OtherFailureNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(BlockFailureNum CallSuccessNum ExtInterruptNum OtherFailureNum)],
		PRODUCE_LIF				=> 'True',
	},

	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Cell_Concurrent_Voice_Paging_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_Concurrent_Voice_Paging-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_Concurrent_Voice_Paging_1X_AGGR_CELL',
		SUM_COUNTERS			=> [qw(BlockFailureNum CallSuccessNum ExtInterruptNum OtherFailureNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(BlockFailureNum CallSuccessNum ExtInterruptNum OtherFailureNum)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Cell_Hard_Handoff_Add_TgtBSS_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Cell_Hard_Handoff_Add_as_target_BSS-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_Hard_Handoff_Add_TgtBSS_1X_AGGR_CELL',
		SUM_COUNTERS			=> [qw(CON_HoAddSuccessNum CON_HoBlockFailureNum CON_HoExtInterruptNum CON_HoOtherFailureNum DATA_HoAddSuccessNum DATA_HoBlockFailureNum DATA_HoExtInterruptNum DATA_HoOtherFailureNum VOC_HoAddSuccessNum VOC_HoBlockFailureNum VOC_HoExtInterruptNum VOC_HoOtherFailureNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(CON_HoAddSuccessNum CON_HoBlockFailureNum CON_HoExtInterruptNum CON_HoOtherFailureNum DATA_HoAddSuccessNum DATA_HoBlockFailureNum DATA_HoExtInterruptNum DATA_HoOtherFailureNum VOC_HoAddSuccessNum VOC_HoBlockFailureNum VOC_HoExtInterruptNum VOC_HoOtherFailureNum)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Cell_Packet_Handoff_ERL_TgtBSS_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_Packet_Handoff_ERL_as_target_BSS-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_Packet_Handoff_ERL_TgtBSS_1X_AGGR_CELL',
		SUM_COUNTERS			=> [qw(SHoDuration SSHoDuration)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(SHoDuration SSHoDuration)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Cell_Packet_Handoff_intraBSS_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_Packet_Handoff_intra_BSS-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_Packet_Handoff_intraBSS_1X_AGGR_CELL',
		SUM_COUNTERS			=> [qw(InterBscHo_HoFNum InterBscHo_HoSNum SrcBscFO_HoFNum SrcBscFO_HoSNum SrcBscFREQ_HoFNum SrcBscFREQ_HoSNum SrcBscOther_HoFNum SrcBscOther_HoSNum SrcBscRC_HoFNum SrcBscRC_HoSNum SrcBscSoftAdd_HoFNum SrcBscSoftAdd_HoSNum SrcBscSofterAdd_HoFNum SrcBscSofterAdd_HoSNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(InterBscHo_HoFNum InterBscHo_HoSNum SrcBscFO_HoFNum SrcBscFO_HoSNum SrcBscFREQ_HoFNum SrcBscFREQ_HoSNum SrcBscOther_HoFNum SrcBscOther_HoSNum SrcBscRC_HoFNum SrcBscRC_HoSNum SrcBscSoftAdd_HoFNum SrcBscSoftAdd_HoSNum SrcBscSofterAdd_HoFNum SrcBscSofterAdd_HoSNum)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Cell_Packet_Handoff_TgtBSS_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_Packet_Handoff_as_target_BSS-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_Packet_Handoff_TgtBSS_1X_AGGR_CELL',
		SUM_COUNTERS			=> [qw(InterBscHo_HoFNum InterBscHo_HoSNum TgtBscFO_HoFNum TgtBscFO_HoSNum TgtBscFREQ_HoFNum TgtBscFREQ_HoSNum TgtBscOther_HoFNum TgtBscOther_HoSNum TgtBscRC_HoFNum TgtBscRC_HoSNum TgtBscSoftAdd_HoFNum TgtBscSoftAdd_HoSNum TgtBscSofterAdd_HoFNum TgtBscSofterAdd_HoSNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(InterBscHo_HoFNum InterBscHo_HoSNum TgtBscFO_HoFNum TgtBscFO_HoSNum TgtBscFREQ_HoFNum TgtBscFREQ_HoSNum TgtBscOther_HoFNum TgtBscOther_HoSNum TgtBscRC_HoFNum TgtBscRC_HoSNum TgtBscSoftAdd_HoFNum TgtBscSoftAdd_HoSNum TgtBscSofterAdd_HoFNum TgtBscSofterAdd_HoSNum)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Cell_Packet_Originating_Call_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_Packet_Originating_Call-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_Packet_Originating_Call_1X_AGGR_CELL',
		SUM_COUNTERS			=> [qw(AccHo_BlockFailureNum AccHo_CallSuccessNum AccHo_ExtInterruptNum AccHo_OtherFailureNum AccProbe_BlockFailureNum AccProbe_CallSuccessNum AccProbe_ExtInterruptNum AccProbe_OtherFailureNum AssignSoft_BlockFailureNum AssignSoft_CallSuccessNum AssignSoft_ExtInterruptNum AssignSoft_OtherFailureNum CMO_BlockFailureNum CMO_CallSuccessNum CMO_ExtInterruptNum CMO_OtherFailureNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(AccHo_BlockFailureNum AccHo_CallSuccessNum AccHo_ExtInterruptNum AccHo_OtherFailureNum AccProbe_BlockFailureNum AccProbe_CallSuccessNum AccProbe_ExtInterruptNum AccProbe_OtherFailureNum AssignSoft_BlockFailureNum AssignSoft_CallSuccessNum AssignSoft_ExtInterruptNum AssignSoft_OtherFailureNum CMO_BlockFailureNum CMO_CallSuccessNum CMO_ExtInterruptNum CMO_OtherFailureNum)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Cell_Packet_Paging_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_Packet_Paging-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_Packet_Paging_1X_AGGR_CELL',
		SUM_COUNTERS			=> [qw(AccHo_BlockFailureNum AccHo_CallSuccessNum AccHo_ExtInterruptNum AccHo_OtherFailureNum AccProbe_BlockFailureNum AccProbe_CallSuccessNum AccProbe_ExtInterruptNum AccProbe_OtherFailureNum AssignSoft_BlockFailureNum AssignSoft_CallSuccessNum AssignSoft_ExtInterruptNum AssignSoft_OtherFailureNum CMO_BlockFailureNum CMO_CallSuccessNum CMO_ExtInterruptNum CMO_OtherFailureNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(AccHo_BlockFailureNum AccHo_CallSuccessNum AccHo_ExtInterruptNum AccHo_OtherFailureNum AccProbe_BlockFailureNum AccProbe_CallSuccessNum AccProbe_ExtInterruptNum AccProbe_OtherFailureNum AssignSoft_BlockFailureNum AssignSoft_CallSuccessNum AssignSoft_ExtInterruptNum AssignSoft_OtherFailureNum CMO_BlockFailureNum CMO_CallSuccessNum CMO_ExtInterruptNum CMO_OtherFailureNum)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Cell_Packet_Release_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_Packet_Release-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_Packet_Release_1X_AGGR_CELL',
		SUM_COUNTERS			=> [qw(CM_NotRadioFNum CM_RadioFNum CM_RlsSNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(CM_NotRadioFNum CM_RadioFNum CM_RlsSNum)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Cell_SMS_Originating_Call_TCH_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_SMS_Originating_Call_on_TCH-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_SMS_Originating_Call_TCH_1X_AGGR_CELL',
		SUM_COUNTERS			=>[qw(AccHo_BlockFailureNum AccHo_CallSuccessNum AccHo_ExtInterruptNum AccHo_OtherFailureNum AccProbe_BlockFailureNum AccProbe_CallSuccessNum AccProbe_ExtInterruptNum AccProbe_OtherFailureNum AssignSoft_BlockFailureNum AssignSoft_CallSuccessNum AssignSoft_ExtInterruptNum AssignSoft_OtherFailureNum CMO_BlockFailureNum CMO_CallSuccessNum CMO_ExtInterruptNum CMO_OtherFailureNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=>[qw(AccHo_BlockFailureNum AccHo_CallSuccessNum AccHo_ExtInterruptNum AccHo_OtherFailureNum AccProbe_BlockFailureNum AccProbe_CallSuccessNum AccProbe_ExtInterruptNum AccProbe_OtherFailureNum AssignSoft_BlockFailureNum AssignSoft_CallSuccessNum AssignSoft_ExtInterruptNum AssignSoft_OtherFailureNum CMO_BlockFailureNum CMO_CallSuccessNum CMO_ExtInterruptNum CMO_OtherFailureNum)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Cell_SMS_Paging_TCH_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_SMS_Paging_on_TCH-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_SMS_Paging_TCH_1X_AGGR_CELL',
		SUM_COUNTERS			=>[qw(AccHo_BlockFailureNum AccHo_CallSuccessNum AccHo_ExtInterruptNum AccHo_OtherFailureNum AccProbe_BlockFailureNum AccProbe_CallSuccessNum AccProbe_ExtInterruptNum AccProbe_OtherFailureNum AssignSoft_BlockFailureNum AssignSoft_CallSuccessNum AssignSoft_ExtInterruptNum AssignSoft_OtherFailureNum CMO_BlockFailureNum CMO_CallSuccessNum CMO_ExtInterruptNum CMO_OtherFailureNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=>[qw(AccHo_BlockFailureNum AccHo_CallSuccessNum AccHo_ExtInterruptNum AccHo_OtherFailureNum AccProbe_BlockFailureNum AccProbe_CallSuccessNum AccProbe_ExtInterruptNum AccProbe_OtherFailureNum AssignSoft_BlockFailureNum AssignSoft_CallSuccessNum AssignSoft_ExtInterruptNum AssignSoft_OtherFailureNum CMO_BlockFailureNum CMO_CallSuccessNum CMO_ExtInterruptNum CMO_OtherFailureNum)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Cell_SMS_Release_TCH_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=>['.*1X_Cell_SMS_Release_on_TCH-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_SMS_Release_TCH_1X_AGGR_CELL',
		SUM_COUNTERS			=>[qw(CM_NormalReleaseNum CM_NotRadioLoseCallingNum CM_RadioLoseCallingNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=>[qw(CM_NormalReleaseNum CM_NotRadioLoseCallingNum CM_RadioLoseCallingNum)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Cell_Voice_Handoff_intraBSS_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_Voice_Handoff_intra_BSS-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_Voice_Handoff_intraBSS_1X_AGGR_CELL',
		SUM_COUNTERS			=>[qw(InterBscHo_HoFNum InterBscHo_HoSNum SrcBscFO_HoFNum SrcBscFO_HoSNum SrcBscFREQ_HoFNum SrcBscFREQ_HoSNum SrcBscOther_HoFNum SrcBscOther_HoSNum SrcBscRC_HoFNum SrcBscRC_HoSNum SrcBscSoftAdd_HoFNum SrcBscSoftAdd_HoSNum SrcBscSofterAdd_HoFNum SrcBscSofterAdd_HoSNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=>[qw(InterBscHo_HoFNum InterBscHo_HoSNum SrcBscFO_HoFNum SrcBscFO_HoSNum SrcBscFREQ_HoFNum SrcBscFREQ_HoSNum SrcBscOther_HoFNum SrcBscOther_HoSNum SrcBscRC_HoFNum SrcBscRC_HoSNum SrcBscSoftAdd_HoFNum SrcBscSoftAdd_HoSNum SrcBscSofterAdd_HoFNum SrcBscSofterAdd_HoSNum)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Cell_Voice_Handoff_TgtBSS_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_Voice_Handoff_as_target_BSS-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_Voice_Handoff_TgtBSS_1X_AGGR_CELL',
		SUM_COUNTERS			=>[qw(InterBscHo_HoFNum InterBscHo_HoSNum TgtBscFO_HoFNum TgtBscFO_HoSNum TgtBscFREQ_HoFNum TgtBscFREQ_HoSNum TgtBscOther_HoFNum TgtBscOther_HoSNum TgtBscRC_HoFNum TgtBscRC_HoSNum TgtBscSoftAdd_HoFNum TgtBscSoftAdd_HoSNum TgtBscSofterAdd_HoFNum TgtBscSofterAdd_HoSNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=>[qw(InterBscHo_HoFNum InterBscHo_HoSNum TgtBscFO_HoFNum TgtBscFO_HoSNum TgtBscFREQ_HoFNum TgtBscFREQ_HoSNum TgtBscOther_HoFNum TgtBscOther_HoSNum TgtBscRC_HoFNum TgtBscRC_HoSNum TgtBscSoftAdd_HoFNum TgtBscSoftAdd_HoSNum TgtBscSofterAdd_HoFNum TgtBscSofterAdd_HoSNum)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Cell_Voice_Originating_Call_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_Voice_Originating_Call-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_Voice_Originating_Call_1X_AGGR_CELL',
		SUM_COUNTERS			=>[qw(AccHo_BlockFailureNum AccHo_CallSuccessNum AccHo_ExtInterruptNum AccHo_OtherFailureNum AccProbe_BlockFailureNum AccProbe_CallSuccessNum AccProbe_ExtInterruptNum AccProbe_OtherFailureNum AssignSoft_BlockFailureNum AssignSoft_CallSuccessNum AssignSoft_ExtInterruptNum AssignSoft_OtherFailureNum CMO_BlockFailureNum CMO_CallSuccessNum CMO_ExtInterruptNum CMO_OtherFailureNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=>[qw(AccHo_BlockFailureNum AccHo_CallSuccessNum AccHo_ExtInterruptNum AccHo_OtherFailureNum AccProbe_BlockFailureNum AccProbe_CallSuccessNum AccProbe_ExtInterruptNum AccProbe_OtherFailureNum AssignSoft_BlockFailureNum AssignSoft_CallSuccessNum AssignSoft_ExtInterruptNum AssignSoft_OtherFailureNum CMO_BlockFailureNum CMO_CallSuccessNum CMO_ExtInterruptNum CMO_OtherFailureNum)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Cell_Voice_Paging_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_Voice_Paging-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_Voice_Paging_1X_AGGR_CELL',
		SUM_COUNTERS			=>[qw(AccHo_BlockFailureNum AccHo_CallSuccessNum AccHo_ExtInterruptNum AccHo_OtherFailureNum AccProbe_BlockFailureNum AccProbe_CallSuccessNum AccProbe_ExtInterruptNum AccProbe_OtherFailureNum AssignSoft_BlockFailureNum AssignSoft_CallSuccessNum AssignSoft_ExtInterruptNum AssignSoft_OtherFailureNum CMO_BlockFailureNum CMO_CallSuccessNum CMO_ExtInterruptNum CMO_OtherFailureNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=>[qw(AccHo_BlockFailureNum AccHo_CallSuccessNum AccHo_ExtInterruptNum AccHo_OtherFailureNum AccProbe_BlockFailureNum AccProbe_CallSuccessNum AccProbe_ExtInterruptNum AccProbe_OtherFailureNum AssignSoft_BlockFailureNum AssignSoft_CallSuccessNum AssignSoft_ExtInterruptNum AssignSoft_OtherFailureNum CMO_BlockFailureNum CMO_CallSuccessNum CMO_ExtInterruptNum CMO_OtherFailureNum)],
		PRODUCE_LIF				=> 'True',
	},

	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Cell_Voice_Release_1X block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_Voice_Release-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'Cell_Voice_Release_1X_AGGR_CELL',
		SUM_COUNTERS			=>[qw(CM_NotRadioFNum CM_RadioFNum CM_RlsSNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=>[qw(CM_NotRadioFNum CM_RadioFNum CM_RlsSNum)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum DO_Cell_Assign_Soft_Call block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*DO_Cell_Assign_Soft_Call-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'DO_Cell_Assign_Soft_Call_AGGR_CELL',
		SUM_COUNTERS			=>[qw(CMO_BlockFailureNum CMO_CallSuccessNum CMO_ExtInterruptNum CMO_InvalidReqNum CMO_OtherFailureNum CMO_RFAccessFailureNum CMT_BlockFailureNum CMT_CallSuccessNum CMT_ExtInterruptNum CMT_InvalidReqNum CMT_OtherFailureNum CMT_RFAccessFailureNum FMT_BlockFailureNum FMT_CallSuccessNum FMT_ExtInterruptNum FMT_InvalidReqNum FMT_OtherFailureNum FMT_RFAccessFailureNum MO_WireNetCallSucNum MT_WireNetSucNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=>[qw(CMO_BlockFailureNum CMO_CallSuccessNum CMO_ExtInterruptNum CMO_InvalidReqNum CMO_OtherFailureNum CMO_RFAccessFailureNum CMT_BlockFailureNum CMT_CallSuccessNum CMT_ExtInterruptNum CMT_InvalidReqNum CMT_OtherFailureNum CMT_RFAccessFailureNum FMT_BlockFailureNum FMT_CallSuccessNum FMT_ExtInterruptNum FMT_InvalidReqNum FMT_OtherFailureNum FMT_RFAccessFailureNum MO_WireNetCallSucNum MT_WireNetSucNum)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum DO_Cell_BSSAP_Call_Failure block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*DO_Cell_BSSAP_Call_Failure-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'DO_Cell_BSSAP_Call_Failure_AGGR_CELL',
		SUM_COUNTERS			=>[qw(CMO_BlockFailureNum CMO_ExtInterruptNum CMO_OtherFailureNum CMT_BlockFailureNum CMT_ExtInterruptNum CMT_OtherFailureNum FMT_BlockFailureNum FMT_ExtInterruptNum FMT_OtherFailureNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=>[qw(CMO_BlockFailureNum CMO_ExtInterruptNum CMO_OtherFailureNum CMT_BlockFailureNum CMT_ExtInterruptNum CMT_OtherFailureNum FMT_BlockFailureNum FMT_ExtInterruptNum FMT_OtherFailureNum)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum DO_Cell_CES_Link_Data block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*DO_Cell_CES_Link_Data-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'DO_Cell_CES_Link_Data_AGGR_CELL',
		SUM_COUNTERS			=>[qw(FailureCapsuleNum SuccessCapsuleNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=>[qw(FailureCapsuleNum SuccessCapsuleNum)],
		PRODUCE_LIF				=> 'True',
	},
    
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum DO_Cell_Common_Call block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=>['.*DO_Cell_Common_Call-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'DO_Cell_Common_Call_AGGR_CELL',
		SUM_COUNTERS			=>[qw(CMO_BlockFNum CMO_CallSNum CMO_ExtInterruptNum CMO_InvalidReqNum CMO_OtherFNum CMO_RFAccessFailureNum CMT_BlockFNum CMT_CallSNum CMT_ExtInterruptNum CMT_InvalidReqNum CMT_OtherFNum CMT_RFAccessFailureNum FMT_BlockFNum FMT_CallSNum FMT_ExtInterruptNum FMT_InvalidReqNum FMT_OtherFNum FMT_RFAccessFailureNum MO_WireNetCallSucNum MT_WireNetSucNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=>[qw(CMO_BlockFNum CMO_CallSNum CMO_ExtInterruptNum CMO_InvalidReqNum CMO_OtherFNum CMO_RFAccessFailureNum CMT_BlockFNum CMT_CallSNum CMT_ExtInterruptNum CMT_InvalidReqNum CMT_OtherFNum CMT_RFAccessFailureNum FMT_BlockFNum FMT_CallSNum FMT_ExtInterruptNum FMT_InvalidReqNum FMT_OtherFNum FMT_RFAccessFailureNum MO_WireNetCallSucNum MT_WireNetSucNum)],
		PRODUCE_LIF				=> 'True',
	},
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum DO_Cell_Handoff_Tgt_AN block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*DO_Cell_Handoff_As_Target_AN-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'DO_Cell_Handoff_Tgt_AN_AGGR_CELL',
		SUM_COUNTERS			=>[qw(InterANTgtHoIn_ReqestNum InterANTgtHoIn_SuccessNum TgtANTgtHo_AFRReqestNum TgtANTgtHo_AFRSuccessNum TgtANTgtHo_IFRReqestNum TgtANTgtHo_IFRSuccessNum TgtANTgtHo_SFRReqestNum TgtANTgtHo_SFRSuccessNum TgtANTgtHo_SFTReqestNum TgtANTgtHo_SFTSuccessNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=>[qw(InterANTgtHoIn_ReqestNum InterANTgtHoIn_SuccessNum TgtANTgtHo_AFRReqestNum TgtANTgtHo_AFRSuccessNum TgtANTgtHo_IFRReqestNum TgtANTgtHo_IFRSuccessNum TgtANTgtHo_SFRReqestNum TgtANTgtHo_SFRSuccessNum TgtANTgtHo_SFTReqestNum TgtANTgtHo_SFTSuccessNum)],
		PRODUCE_LIF				=> 'True',
	},

	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum DO_Cell_Handoff_Intra_AN block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=>['.*DO_Cell_Handoff_Intra_AN-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=>[qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'DO_Cell_Handoff_Intra_AN_AGGR_CELL',
		SUM_COUNTERS			=>[qw(InterANTgtHoOut_RequestNum InterANTgtHoOut_SuccessNum SrcANTgtHo_AFRReqestNum SrcANTgtHo_AFRSuccessNum SrcANTgtHo_IFRRequestNum SrcANTgtHo_IFRSuccessNum SrcANTgtHo_SFRRequestNum SrcANTgtHo_SFRSuccessNum SrcANTgtHo_SFTRequestNum SrcANTgtHo_SFTSuccessNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=>[qw(InterANTgtHoOut_RequestNum InterANTgtHoOut_SuccessNum SrcANTgtHo_AFRReqestNum SrcANTgtHo_AFRSuccessNum SrcANTgtHo_IFRRequestNum SrcANTgtHo_IFRSuccessNum SrcANTgtHo_SFRRequestNum SrcANTgtHo_SFRSuccessNum SrcANTgtHo_SFTRequestNum SrcANTgtHo_SFTSuccessNum)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum DO_Cell_Hard_Handoff block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=>['.*DO_Cell_Hard_Handoff-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=>[qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'DO_Cell_Hard_Handoff_AGGR_CELL',
		SUM_COUNTERS			=>[qw(HardHoAdd_ExtInterruptNum HardHoAdd_ReqestNum HardHoAdd_SuccessNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=>[qw(HardHoAdd_ExtInterruptNum HardHoAdd_ReqestNum HardHoAdd_SuccessNum)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum DO_Cell_Release block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*DO_Cell_Release-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=>[qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'DO_Cell_Release_AGGR_CELL',
		SUM_COUNTERS			=>[qw(PDSNReleaseNum RlsSNum SystemFNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=>[qw(PDSNReleaseNum RlsSNum SystemFNum)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum DO_Cell_RLP_Info block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=> ['.*DO_Cell_RLP_Info-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=>[qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'DO_Cell_RLP_Info_AGGR_CELL',
		SUM_COUNTERS			=>[qw(TxByteNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=>[qw(TxByteNum)],
		PRODUCE_LIF				=> 'True',
	},
	
	{
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum DO_Cell_Session_Setup  block to CBSSB_Cell level',
		INPUT_FILE_DESCRIPTION	=>['.*DO_Cell_Session_Setup-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=>[qw(ServerId BssId BtsId CellId)],
		OUTPUT_BLOCK_NAME		=> 'DO_Cell_Session_Setup_AGGR_CELL',
		SUM_COUNTERS			=>[qw(SetupBlockNum SetupFailureNum SetupSuccessNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=>[qw(SetupBlockNum SetupFailureNum SetupSuccessNum)],
		PRODUCE_LIF				=> 'True',
	},

    # ======================================================
	# SUM blocks to CBSSB_Cell level Complete
	# ======================================================

	# ======================================================
	# Aggregate Cell_Concurrent_ERL_1X block to CBSSB level
	# ======================================================

	# Cell_Concurrent_ERL_1X.AvfRlsReq_KilPrc_CallDur
	# Cell_Concurrent_ERL_1X.AvfRlsReq_KilPrc_SHoDur
	# Cell_Concurrent_ERL_1X.AvfRlsReq_KilPrc_SSHoDur
	# Cell_Concurrent_ERL_1X.AvfSvcAss_AvfAssCmp_CallDur
	# Cell_Concurrent_ERL_1X.AvfSvcAss_AvfAssCmp_SHoDur
	# Cell_Concurrent_ERL_1X.AvfSvcAss_AvfAssCmp_SSHoDur
	# Cell_Concurrent_ERL_1X.AvrAssCmp_AvfRlsReq_CallDur
	# Cell_Concurrent_ERL_1X.AvrAssCmp_AvfRlsReq_ShoDur
	# Cell_Concurrent_ERL_1X.AvrAssCmp_AvfRlsReq_SSHoDur
    #========================================================

	{
        RULE_TYPE               => 'ACCUMULATE',
        RULE_DESC               => 'Aggregate Cell_Concurrent_ERL_1X block to CBSSB level',
        INPUT_FILE_DESCRIPTION	=> ['.*1X_Cell_Concurrent_ERL-#-I\.pif$'],
        COUNTERS_TO_SORT_ON     => [qw(ServerId BssId)],
        AVERAGE_COUNTERS        => [qw(AvfRlsReq_KilPrc_CallDur AvfRlsReq_KilPrc_ShoDur AvfRlsReq_KilPrc_SSHoDur AvfSvcAss_AvfAssCmp_CallDur AvfSvcAss_AvfAssCmp_SHoDur AvfSvcAss_AvfAssCmp_SSHoDur AvrAssCmp_AvfRlsReq_CallDur AvrAssCmp_AvfRlsReq_ShoDur AvrAssCmp_AvfRlsReq_SSHoDur)],
        AVERAGE_APPEND_STR      => "_AVG",
        AVERAGE_NO_APPEND_STR   => [qw(AvfRlsReq_KilPrc_CallDur AvfRlsReq_KilPrc_ShoDur AvfRlsReq_KilPrc_SSHoDur AvfSvcAss_AvfAssCmp_CallDur AvfSvcAss_AvfAssCmp_SHoDur AvfSvcAss_AvfAssCmp_SSHoDur AvrAssCmp_AvfRlsReq_CallDur AvrAssCmp_AvfRlsReq_ShoDur AvrAssCmp_AvfRlsReq_SSHoDur)],
        OUTPUT_BLOCK_NAME       => 'Cell_Concurrent_ERL_1X_AGGR_CBSSB',
        PRODUCE_LIF             => 'True',
	},

	{
        RULE_TYPE               => 'ACCUMULATE',
        RULE_DESC               => 'Aggregate Cell_Packet_ERL_BSSAP_1X block to CBSSB level',
        INPUT_FILE_DESCRIPTION  =>  ['.*1X_Cell_Packet_ERL_BSSAP_part-#-I\.pif$'],
        COUNTERS_TO_SORT_ON     => [qw(ServerId BssId)],
        AVERAGE_COUNTERS        => [qw(AvfAssReq_AvfSvcAss_CallDur)],
        AVERAGE_APPEND_STR      => "_AVG",
        AVERAGE_NO_APPEND_STR   => [qw(AvfAssReq_AvfSvcAss_CallDur)],
        OUTPUT_BLOCK_NAME       => 'Cell_Packet_ERL_BSSAP_1X_AGGR_CBSSB',
        PRODUCE_LIF             => 'True',
	},
    
	{
        RULE_TYPE               => 'ACCUMULATE',
        RULE_DESC               => 'Aggregate Cell_Packet_ERL_L3_1X block to CBSSB level',
        INPUT_FILE_DESCRIPTION  => ['.*1X_Cell_Packet_ERL_L3_part-#-I\.pif$'],
        COUNTERS_TO_SORT_ON     => [qw(ServerId BssId)],
        AVERAGE_COUNTERS        => [qw(AvfRlsReq_KilPrc_CallDur AvfSvcAss_AvfAssCmp_CallDur AvrAssCmp_AvfRlsReq_CallDur)],
        AVERAGE_APPEND_STR      => "_AVG",
        AVERAGE_NO_APPEND_STR   => [qw(AvfRlsReq_KilPrc_CallDur AvfSvcAss_AvfAssCmp_CallDur AvrAssCmp_AvfRlsReq_CallDur)],
        OUTPUT_BLOCK_NAME       => 'Cell_Packet_ERL_L3_1X_AGGR_CBSSB',
        PRODUCE_LIF             => 'True',
	},
	
	{
        RULE_TYPE               => 'ACCUMULATE',
        RULE_DESC               => 'Aggregate Cell_SMS_ERL_BSSAP_1X block to CBSSB level',
        INPUT_FILE_DESCRIPTION  => ['.*1X_Cell_SMS_ERL_BSSAP_part-#-I\.pif$'],
        COUNTERS_TO_SORT_ON     => [qw(ServerId BssId)],
        AVERAGE_COUNTERS        => [qw(AvfAssReq_AvfSvcAss_CallDur)],
        AVERAGE_APPEND_STR      => "_AVG",
        AVERAGE_NO_APPEND_STR   => [qw(AvfAssReq_AvfSvcAss_CallDur)],
        OUTPUT_BLOCK_NAME       => 'Cell_SMS_ERL_BSSAP_1X_AGGR_CBSSB',
        PRODUCE_LIF             => 'True',
	},
	
	{
        RULE_TYPE               => 'ACCUMULATE',
        RULE_DESC               => 'Aggregate Cell_SMS_ERL_L3_1X block to CBSSB level',
        INPUT_FILE_DESCRIPTION  => ['.*1X_Cell_SMS_ERL_L3_part-#-I\.pif$'],
        COUNTERS_TO_SORT_ON     => [qw(ServerId BssId)],
        AVERAGE_COUNTERS        => [qw(AvfRlsReq_KilPrc_CallDur AvfRlsReq_KilPrc_ShoDur AvfRlsReq_KilPrc_SSHoDur AvfSvcAss_AvfAssCmp_CallDur AvfSvcAss_AvfAssCmp_SHoDur AvfSvcAss_AvfAssCmp_SSHoDur AvrAssCmp_AvfRlsReq_CallDur AvrAssCmp_AvfRlsReq_ShoDur AvrAssCmp_AvfRlsReq_SSHoDur)],
        AVERAGE_APPEND_STR      => "_AVG",
        AVERAGE_NO_APPEND_STR   => [qw(AvfRlsReq_KilPrc_CallDur AvfRlsReq_KilPrc_ShoDur AvfRlsReq_KilPrc_SSHoDur AvfSvcAss_AvfAssCmp_CallDur AvfSvcAss_AvfAssCmp_SHoDur AvfSvcAss_AvfAssCmp_SSHoDur AvrAssCmp_AvfRlsReq_CallDur AvrAssCmp_AvfRlsReq_ShoDur AvrAssCmp_AvfRlsReq_SSHoDur)],
        OUTPUT_BLOCK_NAME       => 'Cell_SMS_ERL_L3_1X_AGGR_CBSSB',
        PRODUCE_LIF             => 'True',
	},
	{
        RULE_TYPE               => 'ACCUMULATE',
        RULE_DESC               => 'Aggregate Cell_Voice_ERL_BSSAP_1X block to CBSSB level',
        INPUT_FILE_DESCRIPTION  => ['.*1X_Cell_Voice_ERL_BSSAP_part-#-I\.pif$'],
        COUNTERS_TO_SORT_ON     => [qw(ServerId BssId)],
        AVERAGE_COUNTERS        => [qw(AvfAssReq_AvfSvcAss_CallDur)],
        AVERAGE_APPEND_STR      => "_AVG",
        AVERAGE_NO_APPEND_STR   => [qw(AvfAssReq_AvfSvcAss_CallDur)],
        OUTPUT_BLOCK_NAME       => 'Cell_Voice_ERL_BSSAP_1X_AGGR_CBSSB',
        PRODUCE_LIF             => 'True',
	},
	{
        RULE_TYPE               => 'ACCUMULATE',
        RULE_DESC               => 'Aggregate Cell_Voice_ERL_L3_1X block to CBSSB level',
        INPUT_FILE_DESCRIPTION  => ['.*1X_Cell_Voice_ERL_L3_part-#-I\.pif$'],
        COUNTERS_TO_SORT_ON     => [qw(ServerId BssId)],
        AVERAGE_COUNTERS        => [qw(AvfRlsReq_KilPrc_CallDur AvfRlsReq_KilPrc_ShoDur AvfRlsReq_KilPrc_SSHoDur AvfSvcAss_AvfAssCmp_CallDur AvfSvcAss_AvfAssCmp_SHoDur AvfSvcAss_AvfAssCmp_SSHoDur AvrAssCmp_AvfRlsReq_CallDur AvrAssCmp_AvfRlsReq_ShoDur AvrAssCmp_AvfRlsReq_SSHoDur)],
        AVERAGE_APPEND_STR      => "_AVG",
        AVERAGE_NO_APPEND_STR   => [qw(AvfRlsReq_KilPrc_CallDur AvfRlsReq_KilPrc_ShoDur AvfRlsReq_KilPrc_SSHoDur AvfSvcAss_AvfAssCmp_CallDur AvfSvcAss_AvfAssCmp_SHoDur AvfSvcAss_AvfAssCmp_SSHoDur AvrAssCmp_AvfRlsReq_CallDur AvrAssCmp_AvfRlsReq_ShoDur AvrAssCmp_AvfRlsReq_SSHoDur)],
        OUTPUT_BLOCK_NAME       => 'Cell_Voice_ERL_L3_1X_AGGR_CBSSB',
        PRODUCE_LIF             => 'True',
	},
	{
        RULE_TYPE               => 'ACCUMULATE',
        RULE_DESC               => 'Aggregate Cell_Voice_Handoff_ERL_TgtBSS_1X block to CBSSB level',
        INPUT_FILE_DESCRIPTION  => ['.*1X_Cell_Voice_Handoff_ERL_as_target_BSS-#-I\.pif$'],
        COUNTERS_TO_SORT_ON     => [qw(ServerId BssId)],
        AVERAGE_COUNTERS        => [qw(SHoDuration SSHoDuration)],
        AVERAGE_APPEND_STR      => "_AVG",
        AVERAGE_NO_APPEND_STR   => [qw(SHoDuration SSHoDuration)],
        OUTPUT_BLOCK_NAME       => 'Cell_Voice_Handoff_ERL_TgtBSS_1X_AGGR_CBSSB',
        PRODUCE_LIF             => 'True',
	},
	
	{
        RULE_TYPE               => 'ACCUMULATE',
        RULE_DESC               => 'Aggregate DO_Cell_FCH_ERL block to CBSSB level',
        INPUT_FILE_DESCRIPTION  => ['.*DO_Cell_FCH_ERL-#-I\.pif$'],
        COUNTERS_TO_SORT_ON     => [qw(ServerId BssId)],
        AVERAGE_COUNTERS        => [qw(CallDuration SHoDuration SSHoDuration)],
        AVERAGE_APPEND_STR      => "_AVG",
        AVERAGE_NO_APPEND_STR   => [qw(CallDuration SHoDuration SSHoDuration)],
        OUTPUT_BLOCK_NAME       => 'DO_Cell_FCH_ERL_AGGR_CBSSB',
        PRODUCE_LIF             => 'True',
	},
 
	# ======================================================
	# Aggregation(AVG) of  blocks to CBSSB level complete
	# ======================================================

    # =============================================================================
	# Aggregation(AVG) of PUB_IP_ARIR_Data and PUB_IP_RFS_Data blocks to Carrier level
	# =============================================================================
    
    {
        RULE_TYPE               => 'ACCUMULATE',
        RULE_DESC               => 'Aggregate PUB_IP_ARIR_Data block to Carrier level',
        INPUT_FILE_DESCRIPTION  => ['.*PUB_IP_ARIR_RF_Data-#-I-#-PZ\.pif$'],
        COUNTERS_TO_SORT_ON     => [qw(ServerId BssId CellID CarrierId)],
        AVERAGE_COUNTERS        => [qw(ARIRAvgRSSIInstant_D ARIRAvgRSSIInstant_M ARIRMaxRSSIInstant_D ARIRMaxRSSIInstant_M ARIRMinRSSIInstant_D ARIRMinRSSIInstant_M)],
		REDUNDANT_DATA_COUNTERS => [qw(ARIRAvgRSSIInstant_D_Watt ARIRAvgRSSIInstant_M_Watt ARIRMaxRSSIInstant_D_Watt ARIRMaxRSSIInstant_M_Watt ARIRMinRSSIInstant_D_Watt ARIRMinRSSIInstant_M_Watt)],
		AVERAGE_APPEND_STR      => "_AVG",
        AVERAGE_NO_APPEND_STR   => [qw(ARIRAvgRSSIInstant_D ARIRAvgRSSIInstant_M ARIRMaxRSSIInstant_D ARIRMaxRSSIInstant_M ARIRMinRSSIInstant_D ARIRMinRSSIInstant_M)],
        OUTPUT_BLOCK_NAME       => 'PUB_IP_ARIR_Data_AGGR',
        PRODUCE_PIF             => 'True',
	},
    
	{
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Convert PUB_IP_ARIR_RF_Data counter values to Watts',
        INPUT_FILE_DESCRIPTION => [ '.*PUB_IP_ARIR_RF_Data-#-I-#-PZ-#-PUB_IP_ARIR_Data_AGGR-#-A\.pif$' ],
		
        FILENAME_SUFFIX        => 'PZ',
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;

            my @ctrs2conv = (
                'ARIRMaxRSSIInstant_M',
                'ARIRMinRSSIInstant_M',
				'ARIRAvgRSSIInstant_M',
				'ARIRMaxRSSIInstant_D',
				'ARIRMinRSSIInstant_D',
				'ARIRAvgRSSIInstant_D'
            );
            my ($ctr_name, $new_ctr_name);

            foreach $ctr_name (@ctrs2conv) {

                $new_ctr_name = $ctr_name . "_Watt";
                $c_ref->{$new_ctr_name} = 10**($c_ref->{$ctr_name}/10);

            }

            return 0;
        },
		PRODUCE_LIF             => 'True',
    },    
	
    {
        RULE_TYPE               => 'ACCUMULATE',
        RULE_DESC               => 'Aggregate PUB_IP_RFS_Data block to Carrier level',
        INPUT_FILE_DESCRIPTION  => ['.*PUB_IP_RFS_Data-#-I-#-PZ\.pif$'],
        COUNTERS_TO_SORT_ON     => [qw(ServerId BssId CellID CarrierId)],
        AVERAGE_COUNTERS        => [qw(AvgForwardPower AvgRSSIInstant_D AvgRSSIInstant_M MaxForwardPower MaxRSSIInstant_D MaxRSSIInstant_M MinForwardPower MinRSSIInstant_D MinRSSIInstant_M)],
		REDUNDANT_DATA_COUNTERS => [qw(AvgForwardPower_Watt AvgRSSIInstant_D_Watt AvgRSSIInstant_M_Watt MaxForwardPower_Watt MaxRSSIInstant_D_Watt MaxRSSIInstant_M_Watt MinForwardPower_Watt MinRSSIInstant_D_Watt MinRSSIInstant_M_Watt)],
		AVERAGE_APPEND_STR      => "_AVG",
        AVERAGE_NO_APPEND_STR   => [qw(AvgForwardPower AvgRSSIInstant_D AvgRSSIInstant_M MaxForwardPower MaxRSSIInstant_D MaxRSSIInstant_M MinForwardPower MinRSSIInstant_D MinRSSIInstant_M)],
        OUTPUT_BLOCK_NAME       => 'PUB_IP_RFS_Data_AGGR',
        PRODUCE_PIF             => 'True',
	},
	{
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Convert PUB_IP_RFS_Data counter values to Watts',
		INPUT_FILE_DESCRIPTION => [ '.*PUB_IP_RFS_Data-#-I-#-PZ-#-PUB_IP_RFS_Data_AGGR-#-A\.pif$' ],
		
        FILENAME_SUFFIX        => 'PZ',
        DATA_COUNTERS_OP => sub {
            my $c_ref = shift;

            my @ctrs2conv = (
                'MaxForwardPower',
                'MinForwardPower',
                'AvgForwardPower',
                'MaxRSSIInstant_M',
                'MinRSSIInstant_M',
                'AvgRSSIInstant_M',
                'MaxRSSIInstant_D',
                'MinRSSIInstant_D',
                'AvgRSSIInstant_D'
            );
            my ($ctr_name, $new_ctr_name);

            foreach $ctr_name (@ctrs2conv) {

                $new_ctr_name = $ctr_name . "_Watt";
                $c_ref->{$new_ctr_name} = 10**($c_ref->{$ctr_name}/10);
            }

            return 0;
        },
		PRODUCE_LIF             => 'True',
    },

    # ======================================================
	# Aggregation(AVG) of  blocks to Carrier level complete
	# ======================================================




    # ======================================================
	# Aggregation(SUM) of blocks up to CBSSB level Start
	# ======================================================
     
	 {
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Global_Concurrent_Packet_Originating_Call_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Global_Concurrent_Packet_Originating_Call-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'Global_Concurrent_Packet_Originating_Call_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(CallSuccessNum ExtInterruptNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(CallSuccessNum ExtInterruptNum)],
		PRODUCE_LIF				=> 'True',
	 },
	
	 {
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Global_Concurrent_Packet_Paging_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Global_Concurrent_Packet_Paging-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'Global_Concurrent_Packet_Paging_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(CallSuccessNum ExtInterruptNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(CallSuccessNum ExtInterruptNum)],
		PRODUCE_LIF				=> 'True',
	 },

	 {
		RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Global_Concurrent_Release_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Global_Concurrent_Release-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'Global_Concurrent_Release_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(ConVoc_RlsFailNum ConVoc_RlsSuccNum ConVocData_RlsFailNum ConVocData_RlsSuccNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(ConVoc_RlsFailNum ConVoc_RlsSuccNum ConVocData_RlsFailNum ConVocData_RlsSuccNum)],
		PRODUCE_LIF				=> 'True',
	 },
	
	 {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Global_Concurrent_Voice_Originating_Call_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Global_Concurrent_Voice_Originating_Call-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'Global_Concurrent_Voice_Originating_Call_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(BlockFailureNum CallSuccessNum ExtInterruptNum OtherFailureNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(BlockFailureNum CallSuccessNum ExtInterruptNum OtherFailureNum)],
		PRODUCE_LIF				=> 'True',
	 },
	
	 {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Global_Concurrent_Voice_Paging_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Global_Concurrent_Voice_Paging-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'Global_Concurrent_Voice_Paging_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(BlockFailureNum CallSuccessNum ExtInterruptNum OtherFailureNum PageResponceNum PagingMsNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(BlockFailureNum CallSuccessNum ExtInterruptNum OtherFailureNum PageResponceNum PagingMsNum)],
		PRODUCE_LIF				=> 'True',
	 },
	
	 {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Global_Hard_Handoff_Add_TgtBSS_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Global_Hard_Handoff_Add_as_target_BSS-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'Global_Hard_Handoff_Add_TgtBSS_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(CON_HoAddSuccessNum CON_HoBlockFailureNum CON_HoExtInterruptNum CON_HoOtherFailureNum DATA_HoAddSuccessNum DATA_HoBlockFailureNum DATA_HoExtInterruptNum DATA_HoOtherFailureNum VOC_HoAddSuccessNum VOC_HoBlockFailureNum VOC_HoExtInterruptNum VOC_HoOtherFailureNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(CON_HoAddSuccessNum CON_HoBlockFailureNum CON_HoExtInterruptNum CON_HoOtherFailureNum DATA_HoAddSuccessNum DATA_HoBlockFailureNum DATA_HoExtInterruptNum DATA_HoOtherFailureNum VOC_HoAddSuccessNum VOC_HoBlockFailureNum VOC_HoExtInterruptNum VOC_HoOtherFailureNum)],
		PRODUCE_LIF				=> 'True',
	 },

     {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Global_Hard_Handoff_Drop_SourceBSS_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Global_Hard_Handoff_Drop_as_source_BSS-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'Global_Hard_Handoff_Drop_SourceBSS_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(Con_HoDropNum ConcCurHoOtherFailNum ConCurHoNormalFailNum Data_HoDropNum DataHoNormalFailNum DataHoOtherFailNum Voc_HoDropNum VocHoNormalFailNum VocHoOtherFailNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(Con_HoDropNum ConcCurHoOtherFailNum ConCurHoNormalFailNum Data_HoDropNum DataHoNormalFailNum DataHoOtherFailNum Voc_HoDropNum VocHoNormalFailNum VocHoOtherFailNum)],
		PRODUCE_LIF				=> 'True',
	 },

	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Global_Packet_Handoff_IntraBSS_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Global_Packet_Handoff_intra_BSS-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'Global_Packet_Handoff_IntraBSS_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(InterBscHo_HoFNum InterBscHo_HoSNum SrcBscFO_HoFNum SrcBscFO_HoSNum SrcBscFREQ_HoFNum SrcBscFREQ_HoSNum SrcBscRC_HoFNum SrcBscRC_HoSNum SrcBscSoftAdd_HoFNum SrcBscSoftAdd_HoSNum SrcBscSofterAdd_HoFNum SrcBscSofterAdd_HoSNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(InterBscHo_HoFNum InterBscHo_HoSNum SrcBscFO_HoFNum SrcBscFO_HoSNum SrcBscFREQ_HoFNum SrcBscFREQ_HoSNum SrcBscRC_HoFNum SrcBscRC_HoSNum SrcBscSoftAdd_HoFNum SrcBscSoftAdd_HoSNum SrcBscSofterAdd_HoFNum SrcBscSofterAdd_HoSNum)],
		PRODUCE_LIF				=> 'True',
	  },

	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Global_Packet_Handoff_TgtBSS_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Global_Packet_Handoff_as_target_BSS-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'Global_Packet_Handoff_TgtBSS_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(InterBscHo_HoFNum InterBscHo_HoSNum TgtBscFO_HoFNum TgtBscFO_HoSNum TgtBscFREQ_HoFNum TgtBscFREQ_HoSNum TgtBscRC_HoFNum TgtBscRC_HoSNum TgtBscSoftAdd_HoFNum TgtBscSoftAdd_HoSNum TgtBscSofterAdd_HoFNum TgtBscSofterAdd_HoSNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(InterBscHo_HoFNum InterBscHo_HoSNum TgtBscFO_HoFNum TgtBscFO_HoSNum TgtBscFREQ_HoFNum TgtBscFREQ_HoSNum TgtBscRC_HoFNum TgtBscRC_HoSNum TgtBscSoftAdd_HoFNum TgtBscSoftAdd_HoSNum TgtBscSofterAdd_HoFNum TgtBscSofterAdd_HoSNum)],
		PRODUCE_LIF				=> 'True',
	  },
	  
	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Global_Packet_Originating_Call_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Global_Packet_Originating_Call-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'Global_Packet_Originating_Call_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(AccHo_CallSuccessNum AccHo_ExtInterruptNum AccProbe_CallSuccessNum AccProbe_ExtInterruptNum AssignSoft_CallSuccessNum AssignSoft_ExtInterruptNum CMO_CallSuccessNum CMO_ExtInterruptNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(AccHo_CallSuccessNum AccHo_ExtInterruptNum AccProbe_CallSuccessNum AccProbe_ExtInterruptNum AssignSoft_CallSuccessNum AssignSoft_ExtInterruptNum CMO_CallSuccessNum CMO_ExtInterruptNum)],
		PRODUCE_LIF				=> 'True',
	  },

	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Global_Packet_Paging_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Global_Packet_Paging-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'Global_Packet_Paging_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(AccHo_CallSuccessNum AccHo_ExtInterruptNum AccProbe_CallSuccessNum AccProbe_ExtInterruptNum AssignSoft_CallSuccessNum AssignSoft_ExtInterruptNum CMO_CallSuccessNum CMO_ExtInterruptNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(AccHo_CallSuccessNum AccHo_ExtInterruptNum AccProbe_CallSuccessNum AccProbe_ExtInterruptNum AssignSoft_CallSuccessNum AssignSoft_ExtInterruptNum CMO_CallSuccessNum CMO_ExtInterruptNum)],
		PRODUCE_LIF				=> 'True',
	  },

	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Global_PCF_Call_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Global_PCF_Call-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'Global_PCF_Call_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(DC_CallFNum DC_CallSNum PC_CallFNum PC_CallSNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(DC_CallFNum DC_CallSNum PC_CallFNum PC_CallSNum)],
		PRODUCE_LIF				=> 'True',
	  },
	  
	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Global_PCF_Handoff_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Global_PCF_Handoff-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'Global_PCF_Handoff_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(AA_HandoffFNum AA_HandoffSNum AD_HandoffFNum AD_HandoffSNum DA_HandoffFNum DA_HandoffSNum DD_HandoffFNum DD_HandoffSNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(AA_HandoffFNum AA_HandoffSNum AD_HandoffFNum AD_HandoffSNum DA_HandoffFNum DA_HandoffSNum DD_HandoffFNum DD_HandoffSNum)],
		PRODUCE_LIF				=> 'True',
	  },
	 
	 {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Global_PCF_Release_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Global_PCF_Release-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'Global_PCF_Release_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(A2D_RlsFNum A2D_RlsSNum A2N_RlsFNum A2N_RlsSNum D2N_RlsFNum D2N_RlsSNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(A2D_RlsFNum A2D_RlsSNum A2N_RlsFNum A2N_RlsSNum D2N_RlsFNum D2N_RlsSNum)],
		PRODUCE_LIF				=> 'True',
	  },
	  
	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Global_Registration_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Global_Registration-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'Global_Registration_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(DistanceBasedFailNum DistanceBasedSuccNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(DistanceBasedFailNum DistanceBasedSuccNum)],
		PRODUCE_LIF				=> 'True',
	  },
	
	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Global_SMS_Originating_Call_TCH_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Global_SMS_Originating_Call_on_TCH-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'Global_SMS_Originating_Call_TCH_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(AccHo_BlockFailNum AccHo_CallSuccNum AccHo_ExtInterruptNum AccHo_OtherFailNum AccProbe_BlockFailNum AccProbe_CallSuccNum AccProbe_ExtInterruptNum AccProbe_OtherFailNum AssignSoft_BlockFailNum AssignSoft_CallSuccNum AssignSoft_ExtInterruptNum AssignSoft_OtherFailNum CMO_BlockFailNum CMO_CallSuccNum CMO_ExtInterruptNum CMO_OtherFailNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(AccHo_BlockFailNum AccHo_CallSuccNum AccHo_ExtInterruptNum AccHo_OtherFailNum AccProbe_BlockFailNum AccProbe_CallSuccNum AccProbe_ExtInterruptNum AccProbe_OtherFailNum AssignSoft_BlockFailNum AssignSoft_CallSuccNum AssignSoft_ExtInterruptNum AssignSoft_OtherFailNum CMO_BlockFailNum CMO_CallSuccNum CMO_ExtInterruptNum CMO_OtherFailNum)],
		PRODUCE_LIF				=> 'True',
	  },
	
	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Global_SMS_Paging_TCH_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Global_SMS_Paging_on_TCH-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'Global_SMS_Paging_TCH_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(AccHo_BlockFailureNum AccHo_CallSuccessNum AccHo_ExtInterruptNum AccHo_OtherFailureNum AccHo_PageResponceNum AccHo_PagingMsNum AccProbe_BlockFailureNum AccProbe_CallSuccessNum AccProbe_ExtInterruptNum AccProbe_OtherFailureNum AccProbe_PageResponceNum AccProbe_PagingMsNum AssignSoft_BlockFailureNum AssignSoft_CallSuccessNum AssignSoft_ExtInterruptNum AssignSoft_OtherFailureNum AssignSoft_PageResponceNum AssignSoft_PagingMsNum CMO_BlockFailureNum CMO_CallSuccessNum CMO_ExtInterruptNum CMO_OtherFailureNum CMO_PageResponceNum CMO_PagingMsNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(AccHo_BlockFailureNum AccHo_CallSuccessNum AccHo_ExtInterruptNum AccHo_OtherFailureNum AccHo_PageResponceNum AccHo_PagingMsNum AccProbe_BlockFailureNum AccProbe_CallSuccessNum AccProbe_ExtInterruptNum AccProbe_OtherFailureNum AccProbe_PageResponceNum AccProbe_PagingMsNum AssignSoft_BlockFailureNum AssignSoft_CallSuccessNum AssignSoft_ExtInterruptNum AssignSoft_OtherFailureNum AssignSoft_PageResponceNum AssignSoft_PagingMsNum CMO_BlockFailureNum CMO_CallSuccessNum CMO_ExtInterruptNum CMO_OtherFailureNum CMO_PageResponceNum CMO_PagingMsNum)],
		PRODUCE_LIF				=> 'True',
	  },
	
	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Global_SMS_Release_TCH_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Global_SMS_Release_on_TCH-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'Global_SMS_Release_TCH_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(CM_NormalReleaseNum CM_NotRadioLoseCallingNum CM_RadioLoseCallingNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(CM_NormalReleaseNum CM_NotRadioLoseCallingNum CM_RadioLoseCallingNum)],
		PRODUCE_LIF				=> 'True',
	  },
	
	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Global_Voice_Handoff_intraBSS_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Global_Voice_Handoff_intra_BSS-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'Global_Voice_Handoff_intraBSS_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(InterBscHo_HoFNum InterBscHo_HoSNum SrcBscFO_HoFNum SrcBscFO_HoSNum SrcBscFREQ_HoFNum SrcBscFREQ_HoSNum SrcBscRC_HoFNum SrcBscRC_HoSNum SrcBscSoftAdd_HoFNum SrcBscSoftAdd_HoSNum SrcBscSofterAdd_HoFNum SrcBscSofterAdd_HoSNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(InterBscHo_HoFNum InterBscHo_HoSNum SrcBscFO_HoFNum SrcBscFO_HoSNum SrcBscFREQ_HoFNum SrcBscFREQ_HoSNum SrcBscRC_HoFNum SrcBscRC_HoSNum SrcBscSoftAdd_HoFNum SrcBscSoftAdd_HoSNum SrcBscSofterAdd_HoFNum SrcBscSofterAdd_HoSNum)],
		PRODUCE_LIF				=> 'True',
	  },
	
	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Global_Voice_Handoff_TgtBSS_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Global_Voice_Handoff_as_target_BSS-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'Global_Voice_Handoff_TgtBSS_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(InterBscHo_HoFNum InterBscHo_HoSNum TgtBscFO_HoFNum TgtBscFO_HoSNum TgtBscFREQ_HoFNum TgtBscFREQ_HoSNum TgtBscRC_HoFNum TgtBscRC_HoSNum TgtBscSoftAdd_HoFNum TgtBscSoftAdd_HoSNum TgtBscSofterAdd_HoFNum TgtBscSofterAdd_HoSNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(InterBscHo_HoFNum InterBscHo_HoSNum TgtBscFO_HoFNum TgtBscFO_HoSNum TgtBscFREQ_HoFNum TgtBscFREQ_HoSNum TgtBscRC_HoFNum TgtBscRC_HoSNum TgtBscSoftAdd_HoFNum TgtBscSoftAdd_HoSNum TgtBscSofterAdd_HoFNum TgtBscSofterAdd_HoSNum)],
		PRODUCE_LIF				=> 'True',
	  },
	
	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Global_Voice_Originating_Call_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Global_Voice_Originating_Call-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'Global_Voice_Originating_Call_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(AccHo_BlockFailureNum AccHo_CallSuccessNum AccHo_ExtInterruptNum AccHo_OtherFailureNum AccProbe_BlockFailureNum AccProbe_CallSuccessNum AccProbe_ExtInterruptNum AccProbe_OtherFailureNum AssignSoft_BlockFailureNum AssignSoft_CallSuccessNum AssignSoft_ExtInterruptNum AssignSoft_OtherFailureNum CMO_BlockFailureNum CMO_CallSuccessNum CMO_ExtInterruptNum CMO_OtherFailureNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(AccHo_BlockFailureNum AccHo_CallSuccessNum AccHo_ExtInterruptNum AccHo_OtherFailureNum AccProbe_BlockFailureNum AccProbe_CallSuccessNum AccProbe_ExtInterruptNum AccProbe_OtherFailureNum AssignSoft_BlockFailureNum AssignSoft_CallSuccessNum AssignSoft_ExtInterruptNum AssignSoft_OtherFailureNum CMO_BlockFailureNum CMO_CallSuccessNum CMO_ExtInterruptNum CMO_OtherFailureNum)],
		PRODUCE_LIF				=> 'True',
	  },
	
	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Global_Voice_Paging_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Global_Voice_Paging-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'Global_Voice_Paging_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(AccHo_BlockFailureNum AccHo_CallSuccessNum AccHo_ExtInterruptNum AccHo_OtherFailureNum AccHo_PageResponceNum AccHo_PagingMsNum AccProbe_BlockFailureNum AccProbe_CallSuccessNum AccProbe_ExtInterruptNum AccProbe_OtherFailureNum AccProbe_PageResponceNum AccProbe_PagingMsNum AssignSoft_BlockFailureNum AssignSoft_CallSuccessNum AssignSoft_ExtInterruptNum AssignSoft_OtherFailureNum AssignSoft_PageResponceNum AssignSoft_PagingMsNum CMO_BlockFailureNum CMO_CallSuccessNum CMO_ExtInterruptNum CMO_OtherFailureNum CMO_PageResponceNum CMO_PagingMsNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(AccHo_BlockFailureNum AccHo_CallSuccessNum AccHo_ExtInterruptNum AccHo_OtherFailureNum AccHo_PageResponceNum AccHo_PagingMsNum AccProbe_BlockFailureNum AccProbe_CallSuccessNum AccProbe_ExtInterruptNum AccProbe_OtherFailureNum AccProbe_PageResponceNum AccProbe_PagingMsNum AssignSoft_BlockFailureNum AssignSoft_CallSuccessNum AssignSoft_ExtInterruptNum AssignSoft_OtherFailureNum AssignSoft_PageResponceNum AssignSoft_PagingMsNum CMO_BlockFailureNum CMO_CallSuccessNum CMO_ExtInterruptNum CMO_OtherFailureNum CMO_PageResponceNum CMO_PagingMsNum)],
		PRODUCE_LIF				=> 'True',
	  },
	
	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum Global_Voice_Release_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_Global_Voice_Release-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'Global_Voice_Release_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(CM_NotRadioFNum CM_RadioFNum CM_RlsSNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(CM_NotRadioFNum CM_RadioFNum CM_RlsSNum)],
		PRODUCE_LIF				=> 'True',
	  },
	
	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum DO_Cell_BSSAP_Call_Failure block to CBSSB level',
		 INPUT_FILE_DESCRIPTION => ['.*DO_Cell_BSSAP_Call_Failure-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'DO_Cell_BSSAP_Call_Failure_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(CMO_BlockFailureNum CMO_ExtInterruptNum CMO_OtherFailureNum CMT_BlockFailureNum CMT_ExtInterruptNum CMT_OtherFailureNum FMT_BlockFailureNum FMT_ExtInterruptNum FMT_OtherFailureNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(CMO_BlockFailureNum CMO_ExtInterruptNum CMO_OtherFailureNum CMT_BlockFailureNum CMT_ExtInterruptNum CMT_OtherFailureNum FMT_BlockFailureNum FMT_ExtInterruptNum FMT_OtherFailureNum)],
		PRODUCE_LIF				=> 'True',
	  },

	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum DO_Global_Assign_Soft_Call block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*DO_Global_Assign_Soft_Call-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'DO_Global_Assign_Soft_Call_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(CMO_BlockFailureNum CMO_CallSuccessNum CMO_ExtInterruptNum CMO_InvalidReqNum CMO_OtherFailureNum CMO_RFAccessFailureNum CMT_BlockFailureNum CMT_CallSuccessNum CMT_ExtInterruptNum CMT_InvalidReqNum CMT_OtherFailureNum CMT_RFAccessFailureNum FMT_BlockFailureNum FMT_CallSuccessNum FMT_ExtInterruptNum FMT_InvalidReqNum FMT_OtherFailureNum FMT_RFAccessFailureNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(CMO_BlockFailureNum CMO_CallSuccessNum CMO_ExtInterruptNum CMO_InvalidReqNum CMO_OtherFailureNum CMO_RFAccessFailureNum CMT_BlockFailureNum CMT_CallSuccessNum CMT_ExtInterruptNum CMT_InvalidReqNum CMT_OtherFailureNum CMT_RFAccessFailureNum FMT_BlockFailureNum FMT_CallSuccessNum FMT_ExtInterruptNum FMT_InvalidReqNum FMT_OtherFailureNum FMT_RFAccessFailureNum)],
		PRODUCE_LIF				=> 'True',
	  },
	
	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum DO_Global_Common_Call block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*DO_Global_Common_Call-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'DO_Global_Common_Call_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(CMO_BlockFNum CMO_CallSNum CMO_ExtInterruptNum CMO_InvalidReqNum CMO_OtherFNum CMO_RFAccessFailureNum CMT_BlockFNum CMT_CallSNum CMT_ExtInterruptNum CMT_InvalidReqNum CMT_OtherFNum CMT_RFAccessFailureNum FMT_BlockFNum FMT_CallSNum FMT_ExtInterruptNum FMT_InvalidReqNum FMT_OtherFNum FMT_RFAccessFailureNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(CMO_BlockFNum CMO_CallSNum CMO_ExtInterruptNum CMO_InvalidReqNum CMO_OtherFNum CMO_RFAccessFailureNum CMT_BlockFNum CMT_CallSNum CMT_ExtInterruptNum CMT_InvalidReqNum CMT_OtherFNum CMT_RFAccessFailureNum FMT_BlockFNum FMT_CallSNum FMT_ExtInterruptNum FMT_InvalidReqNum FMT_OtherFNum FMT_RFAccessFailureNum)],
		PRODUCE_LIF				=> 'True',
	  },
	
	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum DO_Global_Handoff_As_Target_AN block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*DO_Global_Handoff_As_Target_AN-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'DO_Global_Handoff_As_Target_AN_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(InterANTgtHoIn_ReqestNum InterANTgtHoIn_SuccessNum TgtANTgtHo_IFRReqestNum TgtANTgtHo_IFRSuccessNum TgtANTgtHo_SFRReqestNum TgtANTgtHo_SFRSuccessNum TgtANTgtHo_SFTReqestNum TgtANTgtHo_SFTSuccessNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(InterANTgtHoIn_ReqestNum InterANTgtHoIn_SuccessNum TgtANTgtHo_IFRReqestNum TgtANTgtHo_IFRSuccessNum TgtANTgtHo_SFRReqestNum TgtANTgtHo_SFRSuccessNum TgtANTgtHo_SFTReqestNum TgtANTgtHo_SFTSuccessNum)],
		PRODUCE_LIF				=> 'True',
	  },
	
	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum DO_Global_Handoff_Intra_AN block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*DO_Global_Handoff_Intra_AN-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'DO_Global_Handoff_Intra_AN_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(InterANTgtHoOut_ReqestNum InterANTgtHoOut_SuccessNum SrcANTgtHo_IFRReqestNum SrcANTgtHo_IFRSuccessNum SrcANTgtHo_SFRReqestNum SrcANTgtHo_SFRSuccessNum SrcANTgtHo_SFTReqestNum SrcANTgtHo_SFTSuccessNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(InterANTgtHoOut_ReqestNum InterANTgtHoOut_SuccessNum SrcANTgtHo_IFRReqestNum SrcANTgtHo_IFRSuccessNum SrcANTgtHo_SFRReqestNum SrcANTgtHo_SFRSuccessNum SrcANTgtHo_SFTReqestNum SrcANTgtHo_SFTSuccessNum)],
		PRODUCE_LIF				=> 'True',
	  },

	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum DO_Global_Hard_Handoff block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*DO_Global_Hard_Handoff-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'DO_Global_Hard_Handoff_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(HardHoAdd_ExtInterruptNum HardHoAdd_ReqestNum HardHoAdd_SuccessNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(HardHoAdd_ExtInterruptNum HardHoAdd_ReqestNum HardHoAdd_SuccessNum)],
		PRODUCE_LIF				=> 'True',
	  },

	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum DO_RLP_Data_Flux block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*DO_RLP_Data_Flux-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'DO_RLP_Data_Flux_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(FwdTransmitBytes RevReceiveByteNum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(FwdTransmitBytes RevReceiveByteNum)],
		PRODUCE_LIF				=> 'True',
	  },
	
	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum BTS_95_CE_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_BTS_95_CE-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'BTS_95_CE_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(Reliable95CENum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(Reliable95CENum)],
		PRODUCE_LIF				=> 'True',
	  },
	
	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum BTS_FCE_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_BTS_FCE-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'BTS_FCE_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(ReliableFCENum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(ReliableFCENum)],
		PRODUCE_LIF				=> 'True',
	  },

	  {
	 	RULE_TYPE				=> 'ACCUMULATE',
		RULE_DESC				=> 'Sum BTS_RCE_1X block to CBSSB level',
		INPUT_FILE_DESCRIPTION  => ['.*1X_BTS_RCE-#-I\.pif$'],
		COUNTERS_TO_SORT_ON		=> [qw(ServerId BssId)],
		OUTPUT_BLOCK_NAME		=> 'BTS_RCE_1X_AGGR_CBSSB',
		SUM_COUNTERS			=> [qw(ReliableRCENum)],
        SUM_APPEND_STR			=> "_SUM",
        SUM_NO_APPEND_STR		=> [qw(ReliableRCENum)],
		PRODUCE_LIF				=> 'True',
	  },
	 

	# ======================================================
	# Aggregation(SUM) of blocks up to CBSSB level end
	# ======================================================
    
    
    {
        RULE_TYPE              => 'PIF_2_OUTPUT',
        RULE_DESC              => 'Create CBSSB_Carrier_AccessChannel_Config LIF',
        OUTPUT_FORMAT          => 'LIF_Writer',
        INPUT_FILE_DESCRIPTION => '.*1X_Cell_Access_Channel_Usage-#-I\.pif$',
        OUTPUT_BLOCK_NAME      => 'CBSSB_Carrier_AccessChannel_Config',
        OUTPUT_FILENAME_START  => 'CBSSB_Carrier_AccessChannel_Config',
        REDUNDANT_DATA_COUNTERS => ['InvalidMessageNum', 'ValidMessageNum', 'TotalMessageNum', 'PeakUtilization', 'MaxPeakUtilization'],        
    },
    
    {
        RULE_TYPE              => 'PIF_2_OUTPUT',
        RULE_DESC              => 'Create CBSSB_Cell_Carrier_Walsh_Config LIF',
        OUTPUT_FORMAT          => 'LIF_Writer',
        INPUT_FILE_DESCRIPTION => '.*1X_Cell_Paging_Channel_Usage-#-I\.pif$',
        OUTPUT_BLOCK_NAME      => 'CBSSB_Cell_Carrier_Walsh_Config',
        OUTPUT_FILENAME_START  => 'CBSSB_Cell_Carrier_Walsh_Config',
        REDUNDANT_DATA_COUNTERS => ['PeakUtilization', 'CanTransmit', 'ActualTransmit'],     
    },
    
    {
        RULE_TYPE              => 'PIF_2_OUTPUT',
        RULE_DESC              => 'Create CBSSB_Service_Config LIF',
        OUTPUT_FORMAT          => 'LIF_Writer',
        INPUT_FILE_DESCRIPTION => '.*DO_A8_Data_Flux-#-I\.pif$',
        OUTPUT_BLOCK_NAME      => 'CBSSB_Service_Config',
        OUTPUT_FILENAME_START  => 'CBSSB_Service_Config',
        REDUNDANT_DATA_COUNTERS => ['BscToPcfDataSize', 'PcfToBscDataSize'],     
    },
    
    {
        RULE_TYPE              => 'PIF_2_OUTPUT',
        RULE_DESC              => 'Create CBSSB_Subsys_Carrier_Service_Config LIF',
        OUTPUT_FORMAT          => 'LIF_Writer',
        INPUT_FILE_DESCRIPTION => '.*DO_Block_Reason-#-I\.pif$',
        OUTPUT_BLOCK_NAME      => 'CBSSB_Subsys_Carrier_Service_Config',
        OUTPUT_FILENAME_START  => 'CBSSB_Subsys_Carrier_Service_Config',
        REDUNDANT_DATA_COUNTERS => ['RABOverLoadNum', 'MacIndexFailureNum', 'LackRvsCENum', 'ReqConnectNum'],     
    },        
    
    {
        RULE_TYPE              => 'PIF_2_OUTPUT',
        RULE_DESC              => 'Create CBSSB_Subsystem_Sunit_Config LIF',
        OUTPUT_FORMAT          => 'LIF_Writer',
        INPUT_FILE_DESCRIPTION => '.*PUB_RTP_Delay_Stat-#-I\.pif$',
        OUTPUT_BLOCK_NAME      => 'CBSSB_Subsystem_Sunit_Config',
        OUTPUT_FILENAME_START  => 'CBSSB_Subsystem_Sunit_Config',
        REDUNDANT_DATA_COUNTERS => ['NbDelaySum', 'NbJitterSum', 'NbDelayCnt', 'NbJitterCnt', 'NbDelayMax', 'NbJitterMax'],     
    },            

    {
        RULE_TYPE              => 'PIF_2_OUTPUT',
        RULE_DESC              => 'Create CBSSB_Subsystem_Unit_Config LIF',
        OUTPUT_FORMAT          => 'LIF_Writer',
        INPUT_FILE_DESCRIPTION => '.*PUB_RTP_Flux_Stat-#-I\.pif$',
        OUTPUT_BLOCK_NAME      => 'CBSSB_Subsystem_Unit_Config',
        OUTPUT_FILENAME_START  => 'CBSSB_Subsystem_Unit_Config',
        REDUNDANT_DATA_COUNTERS => ['RcvOctCnt', 'LostPktCnt', 'SendOctCnt', 'RcvPktCnt', 'SendPktCnt'],     
    },
    
    {
        RULE_TYPE              => 'PIF_2_OUTPUT',
        RULE_DESC              => 'Create CBSSB_System_Sunit_Service_Config LIF',
        OUTPUT_FORMAT          => 'LIF_Writer',
        INPUT_FILE_DESCRIPTION => '.*DO_RLP_Data_Flux-#-I\.pif$',
        OUTPUT_BLOCK_NAME      => 'CBSSB_System_Sunit_Service_Config',
        OUTPUT_FILENAME_START  => 'CBSSB_System_Sunit_Service_Config',
        REDUNDANT_DATA_COUNTERS => ['FwdRetransmitBytes', 'dwNAKSendTimes', 'FwdTransmitBytes', 'FwdBufferOverFlowByteNum', 
        							'dwATRequestReTransmitByteNum', 'dwNAKReceivedTimes', 'dwNAKTimeOuts', 'dwFwdFlowStoppedByteNum', 
        							'dwANRequestReTransmitByteNum', 'RevBufferOverFlowByteNum', 'RevAbortByteNum', 'RevReceiveByteNum'],     
    },    
    
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_FSCH_Setup_TGTBSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_FSCH_Setup_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_FSCH_Setup_TGTBSS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_FSCH_Setup_ITABSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_FSCH_Setup_intra_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_FSCH_Setup_ITABSS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Hard_Handoff_Add_TgtBSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Hard_Handoff_Add_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Hard_Handoff_Add_TgtBSS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Hard_Handoff_Drop_SourceBSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Hard_Handoff_Drop_as_source_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Hard_Handoff_Drop_SourceBSS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Packet_Block_Reason_BSSAP_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Packet_Block_Reason_BSSAP_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Packet_Block_Reason_BSSAP_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Packet_Block_Reason_L3_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Packet_Block_Reason_L3_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Packet_Block_Reason_L3_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Packet_ERL_BSSAP_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Packet_ERL_BSSAP_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Packet_ERL_BSSAP_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Packet_ERL_L3_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Packet_ERL_L3_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Packet_ERL_L3_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Packet_Handoff_TgtBSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Packet_Handoff_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Packet_Handoff_TgtBSS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Packet_Handoff_ERL_TgtBSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Packet_Handoff_ERL_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Packet_Handoff_ERL_TgtBSS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Packet_Handoff_IntraBSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Packet_Handoff_intra_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Packet_Handoff_IntraBSS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_packet_originating_call_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Packet_Originating_Call-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_packet_originating_call_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_packet_originating_call_BSSAP_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Packet_Originating_Call_BSSAP_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_packet_originating_call_BSSAP_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Packet_Paging_BSSAP_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Packet_Paging_BSSAP_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Packet_Paging_BSSAP_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Packet_release_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Packet_Release-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Packet_release_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_registration_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Registration-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_registration_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_RSCH_Setup_TGTBSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_RSCH_Setup_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_RSCH_Setup_TGTBSS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_RSCH_Setup_ITABSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_RSCH_Setup_intra_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_RSCH_Setup_ITABSS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_SMS_Block_Reason_BSSAP_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_SMS_Block_Reason_BSSAP_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_SMS_Block_Reason_BSSAP_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_SMS_Block_Reason_L3_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_SMS_Block_Reason_L3_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_SMS_Block_Reason_L3_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_SMS_ERL_BSSAP_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_SMS_ERL_BSSAP_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_SMS_ERL_BSSAP_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_SMS_ERL_L3_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_SMS_ERL_L3_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_SMS_ERL_L3_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_sms_originating_call_BSSAP_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_SMS_Originating_Call_BSSAP_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_sms_originating_call_BSSAP_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_sms_originating_call_TCH_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_SMS_Originating_Call_on_TCH-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_sms_originating_call_TCH_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_SMS_Paging_BSSAP_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_SMS_Paging_BSSAP_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_SMS_Paging_BSSAP_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_SMS_Paging_TCH_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_SMS_Paging_on_TCH-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_SMS_Paging_TCH_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_SMS_Release_TCH_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_SMS_Release_on_TCH-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_SMS_Release_TCH_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_User_ExtInterruptInfo_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_User_ExtInterrupt_Info-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_User_ExtInterruptInfo_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_User_ExtInterruptInfo_Extended_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_User_ExtInterrupt_Info_Extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_User_ExtInterruptInfo_Extended_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Voice_Block_Reason_BSSAP_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Voice_Block_Reason_BSSAP_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Voice_Block_Reason_BSSAP_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Voice_Block_Reason_L3_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Voice_Block_Reason_L3_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Voice_Block_Reason_L3_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Voice_ERL_BSSAP_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Voice_ERL_BSSAP_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Voice_ERL_BSSAP_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Voice_ERL_L3_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Voice_ERL_L3_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Voice_ERL_L3_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Voice_Handoff_TgtBSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Voice_Handoff_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Voice_Handoff_TgtBSS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Voice_Handoff_ERL_TgtBSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Voice_Handoff_ERL_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Voice_Handoff_ERL_TgtBSS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Voice_Handoff_IntraBSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Voice_Handoff_intra_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Voice_Handoff_IntraBSS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_voice_originating_call_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Voice_Originating_Call-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_voice_originating_call_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_voice_originating_call_BSSAP_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Voice_Originating_Call_BSSAP_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_voice_originating_call_BSSAP_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Voice_Paging_BSSAP_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Voice_Paging_BSSAP_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Voice_Paging_BSSAP_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Voice_release_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Voice_Release-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Voice_release_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PUB_1X_CMPV5CMP_CPU_Usage Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PUB_1XCMP_V5CMP_CPU_Usage-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PUB_1X_CMPV5CMP_CPU_Usage',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Forward_Power_Status_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Forward_power_status_statistic-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Forward_Power_Status_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Hard_Handoff_Add_TgtBSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Hard_Handoff_Add_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Hard_Handoff_Add_TgtBSS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Hard_Handoff_Drop_SourceBSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Hard_Handoff_Drop_as_source_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Hard_Handoff_Drop_SourceBSS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Packet_Block_Reason_BSSAP_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Packet_Block_Reason_BSSAP_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Packet_Block_Reason_BSSAP_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Packet_Block_Reason_L3_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Packet_Block_Reason_L3_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Packet_Block_Reason_L3_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Packet_ERL_BSSAP_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Packet_ERL_BSSAP_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Packet_ERL_BSSAP_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Packet_ERL_L3_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Packet_ERL_L3_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Packet_ERL_L3_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Packet_Handoff_TgtBSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Packet_Handoff_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Packet_Handoff_TgtBSS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Packet_Handoff_IntraBSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Packet_Handoff_intra_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Packet_Handoff_IntraBSS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_packet_originating_call_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Packet_Originating_Call-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_packet_originating_call_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_packet_originating_call_BSSAP_Extended_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Packet_Originating_Call_BSSAP_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_packet_originating_call_BSSAP_Extended_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Packet_Paging_BSSAP_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Packet_Paging_BSSAP_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Packet_Paging_BSSAP_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Packet_release_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Packet_Release-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Packet_release_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_registration_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Registration-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_registration_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_SMS_Block_Reason_BSSAP_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_SMS_Block_Reason_BSSAP_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_SMS_Block_Reason_BSSAP_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_SMS_Block_Reason_L3_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_SMS_Block_Reason_L3_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_SMS_Block_Reason_L3_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_SMS_ERL_BSSAP_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_SMS_ERL_BSSAP_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_SMS_ERL_BSSAP_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_SMS_ERL_L3_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_SMS_ERL_L3_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_SMS_ERL_L3_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_sms_originating_call_BSSAP_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_SMS_Originating_Call_BSSAP_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_sms_originating_call_BSSAP_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_sms_originating_call_TCH_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_SMS_Originating_Call_on_TCH-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_sms_originating_call_TCH_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_SMS_Paging_BSSAP_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_SMS_Paging_BSSAP_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_SMS_Paging_BSSAP_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_SMS_Paging_TCH_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_SMS_Paging_on_TCH-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_SMS_Paging_TCH_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_SMS_Release_TCH_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_SMS_Release_on_TCH-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_SMS_Release_TCH_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_User_ExtInterruptInfo_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_User_ExtInterrupt_Info-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_User_ExtInterruptInfo_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_User_ExtInterruptInfo_Extended_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_User_ExtInterrupt_Info_Extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_User_ExtInterruptInfo_Extended_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Voice_Block_Reason_BSSAP_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Voice_Block_Reason_BSSAP_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Voice_Block_Reason_BSSAP_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Voice_Block_Reason_L3_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Voice_Block_Reason_L3_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Voice_Block_Reason_L3_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Voice_ERL_BSSAP_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Voice_ERL_BSSAP_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Voice_ERL_BSSAP_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Voice_ERL_L3_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Voice_ERL_L3_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Voice_ERL_L3_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Voice_Handoff_TgtBSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Voice_Handoff_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Voice_Handoff_TgtBSS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Voice_Handoff_IntraBSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Voice_Handoff_intra_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Voice_Handoff_IntraBSS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Voice_Handover_ERL_TgtBSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Voice_Handoff_ERL_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Voice_Handover_ERL_TgtBSS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_voice_originating_call_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Voice_Originating_Call-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_voice_originating_call_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_voice_originating_call_BSSAP_Extended_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Voice_Originating_Call_BSSAP_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_voice_originating_call_BSSAP_Extended_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Voice_Paging_BSSAP_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Voice_Paging_BSSAP_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Voice_Paging_BSSAP_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Voice_release_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Voice_Release-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Voice_release_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create NO7_Signal_Data_Flow_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_No.7_Signal_Data_Flow_Stat-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'NO7_Signal_Data_Flow_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Cell_CES_link_data Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Cell_CES_Link_Data-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'DO_Cell_CES_link_data',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Cell_Handoff_Tgt_AN Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Cell_Handoff_As_Target_AN-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'DO_Cell_Handoff_Tgt_AN',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Cell_Reverse_Frame Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Cell_Reverse_Frame_Stat-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'DO_Cell_Reverse_Frame',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_CELL_RLP_Info Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Cell_RLP_Info-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'DO_CELL_RLP_Info',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Cell_RTD_Info Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Cell_RTD_info-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'DO_Cell_RTD_Info',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Cell_Call_Handoff_ITABSS Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Cell_Group_Call_Handoff_intra_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Cell_Call_Handoff_ITABSS',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Cell_Broadcast_Rel Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Cell_Broadcast_Release-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Cell_Broadcast_Rel',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Cell_Group_Call_ERL_BSSAP Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Cell_Group_Call_ERL_BSSAP_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Cell_Group_Call_ERL_BSSAP',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Cell_Group_Call_Handoff_TgtBSS Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Cell_Group_Call_Handoff_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Cell_Group_Call_Handoff_TgtBSS',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Cell_Group_Call_HO_ERL_TgTBSS Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Cell_Group_Call_Handoff_ERL_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Cell_Group_Call_HO_ERL_TgTBSS',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Cell_Group_ERL_L3 Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Cell_Group_Call_ERL_L3_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Cell_Group_ERL_L3',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Cell_Group_Originating_Call Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Cell_Group_Call_Originating_Call-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Cell_Group_Originating_Call',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Cell_Group_Paging_Call Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Cell_Group_Call_Paging-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Cell_Group_Paging_Call',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Cell_hard_handoff_add_TgtBSS Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Cell_Hard_Handoff_Add_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Cell_hard_handoff_add_TgtBSS',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Cell_Hard_Handoff_Drop_SrcBSS Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Cell_Hard_Handoff_Drop_as_source_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Cell_Hard_Handoff_Drop_SrcBSS',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Cell_Private_Call_ERL_BSSAP Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Cell_Private_Call_ERL_BSSAP_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Cell_Private_Call_ERL_BSSAP',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Cell_Private_Call_Handoff_ITABSS Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Cell_Private_Call_Handoff_intra_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Cell_Private_Call_Handoff_ITABSS',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Cell_Private_Call_Handoff_TgtBSS Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Cell_Private_Call_Handoff_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Cell_Private_Call_Handoff_TgtBSS',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Cell_Private_Call_HO_ERL_TGTBSS Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Cell_Private_Call_Handoff_ERL_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Cell_Private_Call_HO_ERL_TGTBSS',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Cell_Private_ERL_L3 Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Cell_Private_Call_ERL_L3_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Cell_Private_ERL_L3',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Cell_Private_Originating_Call Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Cell_Private_Call_Originating_Call-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Cell_Private_Originating_Call',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Cell_Private_Paging_Call Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Cell_Private_Call_Paging-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Cell_Private_Paging_Call',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Group_Call_ERL_BSSAP Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Group_Call_ERL_BSSAP_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Global_Group_Call_ERL_BSSAP',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Group_Call_ERL_L3 Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Group_Call_ERL_L3_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Global_Group_Call_ERL_L3',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Group_Call_Handoff_ERL_TGTBSS Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Group_Call_Handoff_ERL_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Global_Group_Call_Handoff_ERL_TGTBSS',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Group_Call_Handoff_ITABSS Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Group_Call_Handoff_intra_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Global_Group_Call_Handoff_ITABSS',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Group_Call_Handoff_TgtBSS Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Group_Call_Handoff_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Global_Group_Call_Handoff_TgtBSS',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Group_Originating_Call Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Group_Call_Originating_Call-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Global_Group_Originating_Call',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Group_Paging_Call Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Group_Call_Paging-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Global_Group_Paging_Call',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Hard_Handoff_Add_TgtBSS Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Hard_Handoff_Add_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Global_Hard_Handoff_Add_TgtBSS',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Hard_Handoff_Drop_SrcBSS Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Hard_Handoff_Drop_as_source_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Global_Hard_Handoff_Drop_SrcBSS',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Private_Call_ERL_BSSAP Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Private_Call_ERL_BSSAP_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Global_Private_Call_ERL_BSSAP',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Private_Call_ERL_L3 Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Private_Call_ERL_L3_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Global_Private_Call_ERL_L3',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Private_Call_Handoff_ITABSS Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Private_Call_Handoff_intra_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Global_Private_Call_Handoff_ITABSS',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Private_Call_Handoff_TgtBSS Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Private_Call_Handoff_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Global_Private_Call_Handoff_TgtBSS',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Private_Handoff_Call_ERL_TGTBSS Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Private_Call_Handoff_ERL_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Global_Private_Handoff_Call_ERL_TGTBSS',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Private_Originating_Call Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Private_Call_Originating_Call-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Global_Private_Originating_Call',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Private_Paging_Call Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Private_Call_Paging-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PTT_Global_Private_Paging_Call',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PUB_HIRS_ARIR_Data Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PUB_HIRS_ARIR_RF_Data-#-I-#-PZ\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PUB_HIRS_ARIR_Data',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PUB_IP_ARIR_Data Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PUB_IP_ARIR_RF_Data-#-I-#-PZ\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PUB_IP_ARIR_Data',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PUB_PCF_Mac_Flux Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PUB_PCF_Mac_Flux_Stat-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PUB_PCF_Mac_Flux',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PUB_PCF_Media_Flux Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PUB_PCF_Media_Flux_Stat-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PUB_PCF_Media_Flux',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PUB_PCF_Signal_Flux Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PUB_PCF_Signal_Flux_Stat-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PUB_PCF_Signal_Flux',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PUB_RTP_Delay Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PUB_RTP_Delay_Stat-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PUB_RTP_Delay',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PUB_RTP_Flux Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PUB_RTP_Flux_Stat-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PUB_RTP_Flux',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create BTS_95_CE_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_BTS_95_CE-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'BTS_95_CE_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create BTS_FCE_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_BTS_FCE-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'BTS_FCE_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create BTS_RCE_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_BTS_RCE-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'BTS_RCE_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Access_Channel_Usage_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Access_Channel_Usage-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Access_Channel_Usage_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_CES_Link_Data_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_CES_Link_Data-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_CES_Link_Data_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Concurrent_ERL_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Concurrent_ERL-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Concurrent_ERL_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Concurrent_Packet_Originating_Call_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Concurrent_Packet_Originating_Call-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Concurrent_Packet_Originating_Call_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Concurrent_Packet_Paging_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Concurrent_Packet_Paging-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Concurrent_Packet_Paging_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Concurrent_Release_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Concurrent_Release-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Concurrent_Release_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Concurrent_Voice_Originating_Call_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Concurrent_Voice_Originating_Call-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Concurrent_Voice_Originating_Call_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Concurrent_Voice_Paging_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Concurrent_Voice_Paging-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Concurrent_Voice_Paging_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Packet_Flux_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Packet_Flux-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Packet_Flux_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Packet_Paging_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Packet_Paging-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Packet_Paging_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Paging_Channel_Usage_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Paging_Channel_Usage-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Paging_Channel_Usage_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_RC_Call_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_RC_Call-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_RC_Call_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Voice_Paging_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Voice_Paging-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Voice_Paging_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create CIC_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_CIC-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'CIC_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DSPM_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_DSPM-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'DSPM_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Concurrent_ERL_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Concurrent_ERL-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Concurrent_ERL_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Concurrent_Packet_Originating_Call_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Concurrent_Packet_Originating_Call-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Concurrent_Packet_Originating_Call_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Concurrent_Packet_Paging_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Concurrent_Packet_Paging-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Concurrent_Packet_Paging_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Concurrent_Release_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Concurrent_Release-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Concurrent_Release_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Concurrent_Voice_Originating_Call_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Concurrent_Voice_Originating_Call-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Concurrent_Voice_Originating_Call_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Concurrent_Voice_Paging_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Concurrent_Voice_Paging-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Concurrent_Voice_Paging_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Packet_Paging_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Packet_Paging-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Packet_Paging_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_PCF_Block_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_PCF_Block-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_PCF_Block_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_PCF_Call_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_PCF_Call-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_PCF_Call_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_PCF_Entity_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_PCF_Entity-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_PCF_Entity_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_PCF_Handoff_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_PCF_Handoff-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_PCF_Handoff_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_PCF_Release_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_PCF_Release-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_PCF_Release_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_SMS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_SMS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_SMS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Voice_Paging_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Voice_Paging-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Voice_Paging_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create IP_VE_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_IP_VE-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'IP_VE_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create RLP_Data_Flux_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_RLP_Data_Flux-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'RLP_Data_Flux_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create SE_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_SE-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'SE_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Traffic_Channel_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Traffic_Channel-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Traffic_Channel_1X',
	},
	
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_A8_Data_Flux Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_A8_Data_Flux-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Abis_Data_Flux Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Abis_Data_Flux-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Block_Reason Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Block_Reason-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_BTS_CHM1_CE Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_BTS_CHM1_CE-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_BTS_CHM2_CE Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_BTS_CHM2_CE-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Cell_Assign_Soft_Call Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Cell_Assign_Soft_Call-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Cell_BSSAP_Call_Failure Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Cell_BSSAP_Call_Failure-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Cell_Common_Call Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Cell_Common_Call-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Cell_FCH_ERL Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Cell_FCH_ERL-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Cell_Forward_Flux Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Cell_Forward_Flux-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Cell_Handoff_Intra_AN Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Cell_Handoff_Intra_AN-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Cell_Hard_Handoff Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Cell_Hard_Handoff-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Cell_Overload Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Cell_Overload-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Cell_Redirect Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Cell_Redirect-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Cell_Release Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Cell_Release-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Cell_Reverse_Flux Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Cell_Reverse_Flux-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Cell_Session_Setup Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Cell_Session_Setup-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Cell_Virtual_Handoff Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Cell_Virtual_Handoff-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Global_Assign_Soft_Call Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Global_Assign_Soft_Call-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Global_Common_Call Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Global_Common_Call-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Global_Handoff_As_Target_AN Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Global_Handoff_As_Target_AN-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Global_Handoff_Intra_AN Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Global_Handoff_Intra_AN-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Global_Hard_Handoff Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Global_Hard_Handoff-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Global_Paging_Response Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Global_Paging_Response-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Global_PCF_Block Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Global_PCF_Block-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Global_PCF_Call Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Global_PCF_Call-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Global_PCF_Entity Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Global_PCF_Entity-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Global_PCF_Handoff Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Global_PCF_Handoff-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Global_PCF_Release Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Global_PCF_Release-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Global_Release Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Global_Release-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Global_Session_Authentication Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Global_Session_Authentication-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Global_Session_Duration Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Global_Session_Duration-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Global_Session_Handoff Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Global_Session_Handoff-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Global_Session_Negotiation Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Global_Session_Negotiation-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Global_Session_Setup Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Global_Session_Setup-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Global_Session_Setup_And_Connection Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Global_Session_Setup_And_Connection-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Global_Virtual_Handoff Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Global_Virtual_Handoff-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_RLP_Data_Flux Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_RLP_Data_Flux-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_SE Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_SE-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Subnet_Session_Handoff Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Subnet_Session_Handoff-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Subnet_Session_Negotiation Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Subnet_Session_Negotiation-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Subnet_Session_Release Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Subnet_Session_Release-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Subnet_Session_Setup Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Subnet_Session_Setup-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Cell_Broadcast_Call Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Cell_Broadcast_Call-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Cell_Broadcast_ERL Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Cell_Broadcast_ERL-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Cell_Group_Call_Release Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Cell_Group_Call_Release-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Cell_Private_Call_Release Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Cell_Private_Call_Release-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Cell_Registration Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Cell_Registration-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Group_Call_Release Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Group_Call_Release-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Private_Call_Release Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Private_Call_Release-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Registration Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Registration-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Source_BSC_Handoff Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Source_BSC_Handoff-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Target_BSC_Handoff Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Target_BSC_Handoff-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Traditional_Broadcast_Call Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Traditional_Broadcast_Call-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Traditional_Broadcast_ERL Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Traditional_Broadcast_ERL-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PTT_Global_Traditional_Broadcast_Release Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PTT_Global_Traditional_Broadcast_Release-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PUB_ABPM_CPU_Usage Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PUB_ABPM_CPU_Usage-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PUB_CCM_CPU_Usage Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PUB_CCM_CPU_Usage-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PUB_DOCMP_CPU_Usage Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PUB_DOCMP_CPU_Usage-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PUB_DOSDU_CPU_Usage Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PUB_DOSDU_CPU_Usage-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PUB_DSMP_CPU_Usage Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PUB_DSMP_CPU_Usage-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PUB_HGM_CPU_Usage Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PUB_HGM_CPU_Usage-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PUB_HIRS_RFS_Data Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PUB_HIRS_RFS_Data-#-I-#-PZ\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PUB_IP_RFS_Data Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PUB_IP_RFS_Data-#-I-#-PZ\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PUB_OMP_CPU_Usage Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PUB_OMP_CPU_Usage-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PUB_RMP_CPU_Usage Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PUB_RMP_CPU_Usage-#-I\.pif$',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PUB_SPCF_CPU_Usage Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PUB_SPCF_CPU_Usage-#-I\.pif$',
	},
        
	{
        RULE_TYPE              => 'PIF_2_OUTPUT',
        RULE_DESC              => 'Create CBSSB_Server_Cell_Carrier_Config LIF',
        OUTPUT_FORMAT          => 'LIF_Writer',
        INPUT_FILE_DESCRIPTION => '.*PUB_IP_RFS_Data-#-I-#-PZ-#-PUB_IP_RFS_Data_AGGR-#-A-#-PZ\.pif$',
        OUTPUT_BLOCK_NAME      => 'CBSSB_Server_Cell_Carrier_Config',
        OUTPUT_FILENAME_START  => 'CBSSB_Server_Cell_Carrier_Config',
        #REDUNDANT_DATA_COUNTERS => ['InvalidMessageNum', 'ValidMessageNum', 'TotalMessageNum', 'PeakUtilization', 'MaxPeakUtilization'],        
    },

	# Begin - Added in v802007p01
	{
            RULE_TYPE               => 'JOIN',
            RULE_DESC               => 'Join for CBSSB_Board_CPU_Config',
            INPUT_FILE_DESCRIPTION  => [
                                        '(.*)PUB_PP_CPU_Usage-#-I\.pif',
                                        '(.*)PUB_BTS_CPU_Usage-#-I\.pif$',
                                        #'(.*)PUB_MP_CPU_Usage-#-I\.pif$'
                                       ],
            OUTPUT_BLOCK_NAME       => 'CBSSB_Board_CPU_Config',
            COUNTERS_TO_JOIN_ON     => [qw(NETWORK_ID REGION_ID ServerId BssId SystemId SubsystemId UnitId SUNIT BoardName)],
            PRODUCE_PIF             => 'True',
            PRODUCE_LIF             => 'True',
            OUTPUT_FILENAME_START   => 'CBSSB_Board_CPU_Config',
            HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME   => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
            REDUNDANT_DATA_COUNTERS     => [],
            REDUNDANT_DATA_DESCRIPTION  => [],
        
        },
        {
            RULE_TYPE               => 'JOIN',
            RULE_DESC               => 'Join for CBSSB_Abist_E1T1_Config',
            INPUT_FILE_DESCRIPTION  => [
                                        '(.*)PUB_HIRS_Abist_E1_T1_Flux-#-I\.pif',
                                        '(.*)PUB_IP_Abist_E1_T1_Flux-#-I\.pif$',
                                       ],
            OUTPUT_BLOCK_NAME       => 'CBSSB_Abist_E1T1_Config',
            COUNTERS_TO_JOIN_ON     => [qw(NETWORK_ID REGION_ID ServerId BssId BSCSubsystem DTBUnit DTBE1 System BtsSubsystem BtsE1 Direction)],
            PRODUCE_PIF             => 'True',
            PRODUCE_LIF             => 'True',
            OUTPUT_FILENAME_START   => 'CBSSB_Abist_E1T1_Config',
            HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME   => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
            REDUNDANT_DATA_COUNTERS     => [],
            REDUNDANT_DATA_DESCRIPTION  => [],
        
        },
        {
            RULE_TYPE               => 'JOIN',
            RULE_DESC               => 'Join for CBSSB_Subsystem_Config',
            INPUT_FILE_DESCRIPTION  => [
                                        '(.*)DO_BTS_CE-#-I\.pif',
                                        '(.*)1X_BTS_95_CE-#-I\.pif$',
                                        '(.*)1X_BTS_FCE-#-I\.pif',
                                        '(.*)1X_BTS_RCE-#-I\.pif$',
                                       ],
            OUTPUT_BLOCK_NAME       => 'CBSSB_Subsystem_Config',
            COUNTERS_TO_JOIN_ON     => [qw(NETWORK_ID REGION_ID ServerId BssId BtsId SubsystemId)],
            PRODUCE_PIF             => 'True',
            PRODUCE_LIF             => 'True',
            OUTPUT_FILENAME_START   => 'CBSSB_Subsystem_Config',
            HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME   => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
            REDUNDANT_DATA_COUNTERS     => [],
            REDUNDANT_DATA_DESCRIPTION  => [],
        
        },
        {
            RULE_TYPE               => 'JOIN',
            RULE_DESC               => 'Join for CBSSB_Call_Errors_Config',
            INPUT_FILE_DESCRIPTION  => [
                                        '(.*)1X_Voice_Call_Error_Reason-#-I\.pif',
                                        '(.*)1X_Packet_Call_Error_Reason-#-I\.pif$',
                                        '(.*)1X_SMS_Call_Error_Reason-#-I\.pif',
                                       ],
            OUTPUT_BLOCK_NAME       => 'CBSSB_Call_Errors_Config',
            COUNTERS_TO_JOIN_ON     => [qw(NETWORK_ID REGION_ID ServerId BssId BtsId CellId CarrierId ServiceType ServiceSubType ServiceState MSCID CI PN ErrorReason)],
            PRODUCE_PIF             => 'True',
            PRODUCE_LIF             => 'True',
            OUTPUT_FILENAME_START   => 'CBSSB_Call_Errors_Config',
            HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME   => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
            REDUNDANT_DATA_COUNTERS     => [],
            REDUNDANT_DATA_DESCRIPTION  => [],
        
        },
        {
            RULE_TYPE               => 'JOIN',
            RULE_DESC               => 'Join for CBSSB_Office_Carrier_Config',
            INPUT_FILE_DESCRIPTION  => [
                                        '(.*)1X_Global_FSCH_Handoff_as_target_BSS-#-I\.pif',
                                        '(.*)1X_Global_FSCH_Handoff_intra_BSS-#-I\.pif$',
                                        '(.*)1X_Global_RSCH_Handoff_as_target_BSS-#-I\.pif',
                                        '(.*)1X_Global_RSCH_Handoff_intra_BSS-#-I\.pif',
                                        '(.*)1X_Global_Packet_Handoff_intra_BSS-#-I\.pif$',
                                        '(.*)1X_Global_Packet_Handoff_as_target_BSS-#-I\.pif',
                                        '(.*)1X_Global_Voice_Handoff_intra_BSS-#-I\.pif$',
                                        '(.*)1X_Global_Voice_Handoff_as_target_BSS-#-I\.pif',
                                       ],
            OUTPUT_BLOCK_NAME       => 'CBSSB_Office_Carrier_Config',
            COUNTERS_TO_JOIN_ON     => [qw(NETWORK_ID REGION_ID ServerId BssId OfficeId CarrierId)],
            PRODUCE_PIF             => 'True',
            PRODUCE_LIF             => 'True',
            OUTPUT_FILENAME_START   => 'CBSSB_Office_Carrier_Config',
            HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME   => [qw(NEType NodeId START_DATE START_TIME NETWORK_ID REGION_ID)],
            REDUNDANT_DATA_COUNTERS     => [],
            REDUNDANT_DATA_DESCRIPTION  => [],
        
        },
	
		
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_FSCH_Handoff_as_target_BSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_FSCH_Handoff_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_FSCH_Handoff_as_target_BSS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Voice_Originating_Call_L3_extended_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Voice_Originating_Call_L3_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Voice_Originating_Call_L3_extended_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Packet_Originating_Call_L3_extended_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Packet_Originating_Call_L3_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Packet_Originating_Call_L3_extended_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_SMS_Originating_Call_L3_extended_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_SMS_Originating_Call_L3_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_SMS_Originating_Call_L3_extended_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Voice_Paging_L3_extended_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Voice_Paging_L3_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Voice_Paging_L3_extended_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Packet_Paging_Layer_3_extended_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Packet_Paging_L3_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Packet_Paging_Layer_3_extended_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_SMS_Paging_L3_extended_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_SMS_Paging_L3_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_SMS_Paging_L3_extended_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Voice_Originating_Call_L3_extended_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Voice_Originating_Call_L3_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Voice_Originating_Call_L3_extended_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Packet_Originating_Call_L3_extended_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Packet_Originating_Call_L3_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Packet_Originating_Call_L3_extended_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_SMS_Originating_Call_L3_extended_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_SMS_Originating_Call_L3_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_SMS_Originating_Call_L3_extended_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Voice_Paging_L3_extended_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Voice_Paging_L3_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Voice_Paging_L3_extended_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Packet_Paging_Layer_3_extended_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Packet_Paging_L3_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Packet_Paging_Layer_3_extended_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_SMS_Paging_L3_extended_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_SMS_Paging_L3_extended_part-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_SMS_Paging_L3_extended_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Iwf_Originating_Call_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Iwf_Originating_Call-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Iwf_Originating_Call_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Iwf_Paging_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Iwf_Paging-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Iwf_Paging_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_VTTS_Transparent_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_VTTS_Transparent-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_VTTS_Transparent_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Burst_Data_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Burst_Data-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Burst_Data_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Voice_Service_Option_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Voice_Service_Option-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Voice_Service_Option_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Voice_Access_Service_Option_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Voice_Access_Service_Option-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Voice_Access_Service_Option_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create CBSSB_Cell_Neighbor_Config Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Neighbor_Handoff-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'CBSSB_Cell_Neighbor_Config',
	    OUTPUT_FILENAME_START  => 'CBSSB_Cell_Neighbor_Config',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Cell_Neighbor_Handoff_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Cell_Neighbor_Handoff-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Cell_Neighbor_Handoff_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Iwf_Release_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Iwf_Release-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Iwf_Release_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_PCF_Status_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_PCF_Status-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_PCF_Status_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Global_Handoff_As_Target_AN_II Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Global_Handoff_II_As_Target_AN-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'DO_Global_Handoff_As_Target_AN_II',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_Global_Handoff_Intra_AN_II Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*DO_Global_Handoff_II_Intra_AN-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'DO_Global_Handoff_Intra_AN_II',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_FSCH_Handoff_intra_BSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_FSCH_Handoff_intra_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_FSCH_Handoff_intra_BSS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_RSCH_Handoff_as_target_BSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_RSCH_Handoff_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_RSCH_Handoff_as_target_BSS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_RSCH_Handoff_intra_BSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_RSCH_Handoff_intra_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_RSCH_Handoff_intra_BSS_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PUB_IP_Abist_Interface_E1_T1_Flows Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PUB_IP_Abist_E1_T1_Flux-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PUB_IP_Abist_Interface_E1_T1_Flows',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create PUB_HIRS_Abist_Interface_E1_T1_Flows Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*PUB_HIRS_Abist_E1_T1_Flux-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'PUB_HIRS_Abist_Interface_E1_T1_Flows',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Voice_Call_Error_Reason_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Voice_Call_Error_Reason-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Voice_Call_Error_Reason_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Packet_Call_Error_Reason_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Packet_Call_Error_Reason-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Packet_Call_Error_Reason_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create SMS_Call_Error_Reason_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_SMS_Call_Error_Reason-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'SMS_Call_Error_Reason_1X',
	},
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create Global_Packet_Handoff_ERL_as_target_BSS_1X Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => '.*1X_Global_Packet_Handoff_ERL_as_target_BSS-#-I\.pif$',
	    OUTPUT_BLOCK_NAME      => 'Global_Packet_Handoff_ERL_as_target_BSS_1X',
	},
	
	{
	    RULE_TYPE              => 'PIF_2_OUTPUT',
	    RULE_DESC              => 'Create DO_A8_Data_Flux Lif',
	    OUTPUT_FORMAT          => 'LIF_Writer',
	    INPUT_FILE_DESCRIPTION => [
					'.*PUB_PP_CPU_Usage-#-I\.pif',
                                        '.*PUB_BTS_CPU_Usage-#-I\.pif$',
                                        '.*PUB_MP_CPU_Usage-#-I\.pif$',
					'.*DO_Global_Common_Call_II-#-I\.pif$',
					'.*DO_Global_Assign_Soft_Call_II-#-I\.pif$',
					'.*DO_Global_Hard_Handoff_II-#-I\.pif$',
					'.*DO_Global_Release_II-#-I\.pif$',
					'.*DO_Cell_Session_Negotiation-#-I\.pif$',
					'.*DO_Cell_Session_Authentication-#-I\.pif$',
					'.*DO_BTS_CE-#-I\.pif$',
					'.*DO_Cell_DRC_Requested_Forward_Rate-#-I\.pif$',
				       ],
	},
    
			
	# End
    
);


sub postparser_config {
    return \@rules;
}

1;
